import requests
import json
import pandas as pd
import time
import urllib3
from datetime import datetime
from chinese_calendar import is_holiday
import datetime
from ngwshare.utils.http_util import get_ua


def day_offset(nums, ndate):
    today = datetime.datetime.strptime(ndate, "%Y-%m-%d").date()  # 将字符串日期转换为datetime格式的日期
    count = 0
    tom_date = today
    one = datetime.timedelta(days=1)
    while count < abs(nums):
        #往后延一日后的时间
        tom_date = tom_date + one if nums > 0 else tom_date - one
        d_wd = tom_date.weekday() + 1
        if is_holiday(tom_date) or d_wd == 6 or d_wd == 7:
            continue
        count += 1
    return datetime.datetime.strftime(tom_date, "%Y-%m-%d")

def day_filter(startDate,endDate):
    hol_day = []
    tra_day = []
    startDate = datetime.datetime.strptime(startDate, "%Y-%m-%d").date()
    endDate = datetime.datetime.strptime(endDate, "%Y-%m-%d").date()
    # 中国的节假日日期数组
    while startDate <= endDate:
        if is_holiday(startDate) or startDate.weekday() == 6 or startDate.weekday() == 7:
            hol_day.append(datetime.datetime.strftime(startDate, "%Y-%m-%d"))  # 节假日+1
        else:
            tra_day.append(datetime.datetime.strftime(startDate, "%Y-%m-%d"))
        startDate += datetime.timedelta(days=1)
    # 返回工作日
    return len(tra_day)


def get_north_jg(sdate, edate):
    url = "https://stq.niuguwang.com/NorthJg/GetNorthJg/data"
    days = day_filter(sdate, edate)
    # print(days)
    if days >= 20:
        raise Exception("超出查询时间区间，限制日期区间内交易日天数为20日")
    parms = {
        'sdate': sdate,  # 发送给服务器的内容
        'edate': edate
    }
    # headers = {
    #     'User-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/90.0.4430.212 Safari/537.36',
    #     'Spam': 'Eggs',
    #     'Connection': 'close'
    # }
    headers = {
        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/90.0.4430.212 Safari/537.36',
    }
    urllib3.disable_warnings()
    # s = time.time()
    res = requests.post(url, data=parms, headers=headers, verify=False, timeout=60)  # 发送请求
    text = res.text
    dict = json.loads(text)
    df = pd.DataFrame(dict)
    # e = time.time()
    # print(e-s)
    return df

def get_free_value(ticker, sdate, edate):
    url = "https://stq.niuguwang.com/NorthJg/GetNorthJg/freevalue"
    # url = "http://127.0.0.1:5000/NorthJg/GetNorthJg/ho"
    # url = "http://dev-www.test.niuguwang/NorthJg/GetNorthJg/freevalue"
    parms = {
        'sdate': sdate,  # 发送给服务器的内容
        'edate': edate,
        'ticker': str(ticker)
    }
    headers = {
        'User-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/90.0.4430.212 Safari/537.36'
    }
    urllib3.disable_warnings()
    res = requests.post(url, data=parms, headers=headers, verify=False, timeout=600)  # 发送请求
    text = res.text
    # print(text)
    dict = json.loads(text)
    df = pd.DataFrame(dict)
    return df




def get_weight_date(index_code, sdate, edate):
    url = "https://stq.niuguwang.com/NorthJg/GetNorthJg/hsweight"
    # url = "http://127.0.0.1:5000/NorthJg/GetNorthJg/freevalue"
    # url = "http://dev-www.test.niuguwang/NorthJg/GetNorthJg/hsweight"
    parms = {
        'sdate': sdate,  # 发送给服务器的内容
        'edate': edate,
        'index_code': index_code
    }
    # print(parms)
    headers = {
        'User-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/90.0.4430.212 Safari/537.36',
        'Spam': 'Eggs',
        'Connection': 'close'
    }
    urllib3.disable_warnings()
    # s = time.time()
    res = requests.post(url, data=parms, headers=headers, verify=False, timeout=600)  # 发送请求
    text = res.text
    dict = json.loads(text)
    df = pd.DataFrame(dict)
    return df


if __name__ == '__main__':
    t1 = time.time()

    # data = get_north_jg("2020-08-17", "2020-08-19")
    # print(data)

    # data = get_free_value('002615.SZ', "2015-03-09", "2015-03-14")
    # print(data)

    # HS300个股权重
    data = get_weight_date("000300.SH", "2021-06-11", "2021-06-11")
    print(data)


    print(time.time()-t1)





__author__ = 'wangjian'
from ngwshare.utils.http_util import get_ua
import requests
import traceback
import json
import pandas as pd


def get_hxl2():
    try:
        url = "https://stq.niuguwang.com/zljl/hxl2"
        headers = {'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('resultCode') == 0:
                return pd.DataFrame(response_json.get('data'))
            else:
                return pd.DataFrame()
        except:
            return pd.DataFrame()

if __name__ == '__main__':
    data = get_hxl2()
    print(data)




# # 日志输出到文件
# import logging
# import datetime
#
# logger = logging.getLogger()
#
# # a 追加   w 覆盖
# logging.basicConfig(
#     level=logging.INFO,
#     # filename='/home/wj/Desktop/STQDataApi/web/log/{}.txt'.format(str(datetime.datetime.now().date())),
#     # filename='./log/{}.txt'.format(str(datetime.datetime.now().date())),
#
#     # filename='/home/wangjian/software/python3.7/lib/python3.7/site-packages/ngshare/log/{}.txt'.format(str(datetime.datetime.now().date())),
#     filename='/home/wangjian/.local/lib/python3.7/site-packages/ngshare/log/{}.txt'.format(str(datetime.datetime.now().date())),
#
#     # filename='/usr/local/lib/python3.7/site-packages/ngshare/log/{}.txt'.format(str(datetime.datetime.now().date())),
#     # filename='C:\\Program Files\\python\\python37\Lib\\site-packages\\ngshare\\log\\{}.txt'.format(str(datetime.datetime.now().date())),
#     # filename='D:\\anaconda\Lib\\site-packages\\ngshare\\log\\{}.txt'.format(str(datetime.datetime.now().date())),
#     # filename='D:\\Anaconda3\\Lib\\site-packages\\ngshare\\log\\{}.txt'.format(str(datetime.datetime.now().date())),
#     # filename='D:\\anaconda3.8\\Lib\\site-packages\\ngshare\\log\\{}.txt'.format(str(datetime.datetime.now().date())),
#
#     # 券商
#     # filename='/home/admin/codes/software/python3.7/lib/python3.7/site-packages/ngshare/log/{}.txt'.format(str(datetime.datetime.now().date())),
#
#
#     # filename='/home/wangjian/.virtualenvs/strategy1/lib/python3.7/site-packages/ngshare/log/{}.txt'.format(str(datetime.datetime.now().date())),
#     # filename='/home/wangjian/.virtualenvs/strategy2/lib/python3.7/site-packages/ngshare/log/{}.txt'.format(str(datetime.datetime.now().date())),
#     # filename='/home/wangjian/.virtualenvs/strategy3/lib/python3.7/site-packages/ngshare/log/{}.txt'.format(str(datetime.datetime.now().date())),
#     # filename='/home/wangjian/.virtualenvs/strategy4/lib/python3.7/site-packages/ngshare/log/{}.txt'.format(str(datetime.datetime.now().date())),
#     # filename='/home/wangjian/.virtualenvs/strategy5/lib/python3.7/site-packages/ngshare/log/{}.txt'.format(str(datetime.datetime.now().date())),
#     # filename='/home/wangjian/.virtualenvs/strategy6/lib/python3.7/site-packages/ngshare/log/{}.txt'.format(str(datetime.datetime.now().date())),
#     # filename='/home/wangjian/.virtualenvs/strategy7/lib/python3.7/site-packages/ngshare/log/{}.txt'.format(str(datetime.datetime.now().date())),
#     filemode='a+',
#     format="%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s:%(message)s")
#
# if __name__ == '__main__':
#     def print(message1=None,message2=None,message3=None,message4=None):
#         str1 = ''
#         if message1:
#             str1 = str(message1)
#         if message2:
#             str1 = str(message1)+str(message2)
#         if message3:
#             str1 = str(message1)+str(message2)+str(message3)
#         if message4:
#             str1 = str(message1)+str(message2)+str(message3)+str(message4)
#         logger.info(str1)
#
#
#     # logger.debug('11111111111..........')
#     # logger.info('222222222.............')
#     # logger.warning('333333333...........')
#     # logger.error('44444444444..............')
#     # logger.critical('55555555555............')
#
#     print([1,32,1], "%s只股票没检索到行业名称" % len([0,21,123]))
#     print('asdasd')



__author__ = 'wangjian'
import datetime
import time
import ngwshare as ng
import pandas as pd


def getTradingCalendar():
    body = {
        "table": 'QT_TradingDayNew',
        "field_list": ['TradingDate', 'IfTradingDay', 'SecuMarket'],
        "alterField": 'TradingDate',
        "startDate": '2018-01-01',
        "endDate": '2023-01-01'
    }
    data = ng.get_fromDate(body)
    return data


def is_trading_day(date=None,data=pd.DataFrame()):
    date = str(date)[:10]+' 00:00:00'
    if data.empty:
        body = {
                "table": 'QT_TradingDayNew',
                "field_list": ['TradingDate', 'IfTradingDay', 'SecuMarket'],
                "alterField": 'TradingDate',
                "startDate": '2018-01-01',
                "endDate": '2023-01-01'
        }
        data = ng.get_fromDate(body)
    data = data.loc[data.SecuMarket==83].drop('SecuMarket',axis=1)
    # print(data)
    flag = data.loc[data.TradingDate==date].IfTradingDay.values[0]
    if flag == 1:
        return True
    else:
        return False


def return_last_trading_day(date=None,data=pd.DataFrame()):
    if date:
        if isinstance(date,str):
            if len(date) == 10:
                now_date = datetime.datetime.strptime(date, '%Y-%m-%d')
            elif len(date) == 19:
                now_date =  datetime.datetime.strptime(date, '%Y-%m-%d %H:%M:%S')
            else:
                now_date = datetime.datetime.strptime(date, '%Y-%m-%dT%H:%M:%S.%f')
        elif isinstance(date, datetime.date):
            now_date = date
        else:
            now_date = datetime.datetime.now()
    else:
        now_date = datetime.datetime.now()
    if data.empty:
        body = {
                "table": 'QT_TradingDayNew',
                "field_list": ['TradingDate', 'IfTradingDay', 'SecuMarket'],
                "alterField": 'TradingDate',
                "startDate": '2018-01-01',
                "endDate": '2023-01-01'
        }
        data = ng.get_fromDate(body)
    data = data.loc[data.SecuMarket==83].drop('SecuMarket',axis=1)
    while True:
            l_date = now_date - datetime.timedelta(days=1)
            l_date = str(l_date)[:10] + ' 00:00:00'
            l_flag = data.loc[data.TradingDate == l_date].IfTradingDay.values[0]
            if l_flag == 1:
                return str(l_date)[:10]
            else:
                now_date = datetime.datetime.strptime(l_date, '%Y-%m-%d %H:%M:%S')
                continue


def return_next_trading_day(date=None, data=pd.DataFrame()):
    if date:
        if isinstance(date,str):
            if len(date) == 10:
                now_date = datetime.datetime.strptime(date, '%Y-%m-%d')
            elif len(date) == 19:
                now_date =  datetime.datetime.strptime(date, '%Y-%m-%d %H:%M:%S')
            else:
                now_date = datetime.datetime.strptime(date, '%Y-%m-%dT%H:%M:%S.%f')
        elif isinstance(date, datetime.date):
            now_date = date
        else:
            now_date = datetime.datetime.now()
    else:
        now_date = datetime.datetime.now()

    if data.empty:
        body = {
                "table": 'QT_TradingDayNew',
                "field_list": ['TradingDate', 'IfTradingDay', 'SecuMarket'],
                "alterField": 'TradingDate',
                "startDate": '2018-01-01',
                "endDate": '2023-01-01'
        }
        data = ng.get_fromDate(body)
    data = data.loc[data.SecuMarket==83].drop('SecuMarket',axis=1)

    while True:
            l_date = now_date + datetime.timedelta(days=1)
            l_date = str(l_date)[:10] + ' 00:00:00'
            l_flag = data.loc[data.TradingDate == l_date].IfTradingDay.values[0]
            if l_flag == 1:
                return str(l_date)[:10]
            else:
                now_date = datetime.datetime.strptime(l_date, '%Y-%m-%d %H:%M:%S')
                continue


if __name__ == '__main__':
    data = getTradingCalendar()
    print(data)

    aa = is_trading_day('2020-10-09',data)
    print(aa)

    aa = is_trading_day('2020-10-01',data)
    print(aa)

    t1111 = time.time()


    da = return_last_trading_day('2020-09-30',data)
    print(da)

    da = return_last_trading_day(data=data)
    print(da)



    print(time.time()-t1111)


    da = return_next_trading_day('2020-10-09',data)
    print(da)

    da = return_next_trading_day(data=data)
    print(da)




__author__ = 'wangjian'
import pyodbc

from ngwshare.constants import ODBC_D

class ODBC:
    def __init__(self,server,uid,pwd,db,DRIVER='{SQL Server}'):
        self.server = server
        self.uid = uid
        self.pwd = pwd
        self.db = db
        # self.DRIVER = '/opt/microsoft/msodbcsql/lib64/libmsodbcsql-13.1.so.9.2'
        # self.DRIVER = '/opt/microsoft/msodbcsql17/lib64/libmsodbcsql-17.5.so.2.1'  # ubuntu
        self.DRIVER = ODBC_D

    def GetConnect(self):
        if not self.db:
            raise(NameError,'没有设置数据库信息')
        self.conn = pyodbc.connect(SERVER=self.server,UID=self.uid,PWD=self.pwd,DATABASE=self.db,DRIVER=self.DRIVER)
        cur = self.conn.cursor()
        if not cur:
            raise(NameError,'连接数据库失败')
        else:
            return cur

    def ExecQuery(self,sql):
        cur = self.GetConnect()
        cur.execute(sql)
        resList = cur.fetchall()

        self.conn.close()
        return resList

    def ExecNonQuery(self,sql):
        cur = self.GetConnect()
        cur.execute(sql)
        self.conn.commit()
        self.conn.close()


def conn_sqlserver_select(sql=None,sql_info=None):
    host = sql_info.get('host')
    database = sql_info.get('database')
    user = sql_info.get('user')
    password = sql_info.get('password')

    ms = ODBC(server=host, uid=user, pwd=password, db=database)
    # ms = ODBC(server=SQL_SERVER_DOMAIN, uid=SQL_SERVER_ACCOUNT, pwd=SQL_SERVER_PASSWORD, db=SQL_SERVER_DATABASE_NAME)
    row = ms.ExecQuery(sql)
    # print(row)
    return row


def conn_sqlserver_insert(sql=None,sql_info=None):
    host = sql_info.get('host')
    database = sql_info.get('database')
    user = sql_info.get('user')
    password = sql_info.get('password')

    ms = ODBC(server=host, uid=user, pwd=password, db=database)
    # ms = ODBC(server=SQL_SERVER_DOMAIN, uid=SQL_SERVER_ACCOUNT, pwd=SQL_SERVER_PASSWORD, db=SQL_SERVER_DATABASE_NAME)
    ms.ExecNonQuery(sql)
    # print('插入成功.')



if __name__ == '__main__':
    import datetime
    import ngwshare as ng
    import time
    import pandas as pd

    # # 测试
    # sql_info = {
    #     'host': '192.168.3.112',
    #     'database': 'DB_IQNgwStrategy',
    #     'user': 'sa',
    #     'password': 'taotao778899!',
    # }
    # # # 生产
    # # sql_info = {
    # #     'host': 'ngwstrategy.mssql.niuguwang',
    # #     'database': 'DB_IQNgwStrategy',
    # #     'user': 'sa',
    # #     'password': 'taotao778899!',
    # # }


    # # 测试
    # sql_info = {
    #     'host': '192.168.3.112',
    #     'database': 'DB_IndependentAccount',
    #     'user': 'sa',
    #     'password': 'taotao778899!',
    # }
    # # # 生产
    # # sql_info = {
    # #     'host': 'ngwstrategy.mssql.niuguwang',
    # #     'database': 'DB_IndependentAccount',
    # #     'user': 'sa',
    # #     'password': 'taotao778899!',
    # # }



    # 测试
    sql_info = {
        'host': '192.168.3.112',
        'database': 'DB_INFORMATION',
        'user': 'sa',
        'password': 'taotao778899!',
    }
    # # 生产
    # sql_info = {
    #     'host': '192.168.2.55',
    #     'database': 'DB_INFORMATION',
    #     'user': 'sa',
    #     'password': 'taotao778899!',
    # }

    t1 = time.time()


    sql = """select InnerCode,FundCode,FundName,RegisterDate,Bonus from FundBonus;"""
    # sql = """select InnerCode,FundCode,FundName,SplitDate,SplitRate from FundSplit;"""
    data = conn_sqlserver_select(sql=sql,sql_info=sql_info)
    data_list = []
    for i in data:
        doc = {
            'innercode':int(i[0]),
            'code': str(i[1]),
            'name': str(i[2]),
            'date': str(i[3])[:10],
            'num': round(float(i[4]),4),
        }
        data_list.append(doc)
    df_data = pd.DataFrame(data_list)
    print(df_data)

    symbol = '511880.SH'
    print(symbol[:6])
    # df_data_code = df_data.loc[df_data['code'] == symbol[:6]].sort_values(["date"], ascending=False)
    df_data_code = df_data.loc[df_data['code'] == symbol[:6]].sort_values(["date"], ascending=False).head(1)
    print(df_data_code)


    print(time.time()-t1)
































import random


def get_ua():
    first_num = random.randint(55, 62)
    third_num = random.randint(0, 3200)
    fourth_num = random.randint(0, 140)
    os_type = [
        "(Windows NT 6.1; WOW64)", "(Windows NT 10.0; WOW64)", "(X11; Linux x86_64)",
        "(Macintosh; Intel Mac OS X 10_12_6)"
    ]
    chrome_version = "Chrome/{}.0.{}.{}".format(first_num, third_num, fourth_num)
    ua = " ".join(["Mozilla/5.0", random.choice(os_type), "AppleWebKit/537.36",
                   "(KHTML, like Gecko)", chrome_version, "Safari/537.36"])
    return ua





import smtplib
from email.mime.text import MIMEText
from email.header import Header
import traceback

def send_mail(to_addr=None,header=None,content=None):
    # # 发信人
    # from_addr = '969282488@qq.com'
    # token = 'kpofdicliftibfcc'

    # 发信人
    from_addr = '296348304@qq.com'
    token = 'jrhflcppohwsbjfj'

    # 收信方邮箱
    # to_addr = '296348304@qq.com'
    # to_addr = 'wj296348304@163.com'

    # 发信服务器
    smtp_server = 'smtp.qq.com'
    try:
        # 邮箱正文内容，第一个参数为内容，第二个参数为格式(plain 为纯文本)，第三个参数为编码
        msg = MIMEText(content, 'plain', 'utf-8')
        # 邮件头信息
        msg['From'] = Header(from_addr)
        msg['To'] = Header(to_addr)
        msg['Subject'] = Header(header)

        server = smtplib.SMTP_SSL(smtp_server)
        server.connect(smtp_server, 465)
        server.login(from_addr, token)
        server.sendmail(from_addr, to_addr, msg.as_string())
        server.quit()
        return True
    except:
        print(traceback.format_exc())
        return False

if __name__ == '__main__':
    to_mail = 'wj296348304@163.com'
    mail_header = '【数据产品】【龙虎榜】'
    mail_content = '[信息]数据保存成功！！！'
    mail_flag = send_mail(to_mail,mail_header,mail_content)
    print(mail_flag)





__author__ = 'wangjian'
from ngwshare.utils.http_util import get_ua
import requests
import traceback
import json
import pandas as pd
import time



def get_SearchData(start=None,end=None):
    start = start.replace('-', '').replace(':', '').replace(' ', '')
    end = end.replace('-', '').replace(':', '').replace(' ', '')
    try:
        url = "https://stq.niuguwang.com/zljl/search?start={}&end={}".format(start,end)
        headers = {'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('resultCode') == 0:
                df_data = pd.DataFrame(response_json.get('data'))
                return df_data
            else:
                return None
        except:
            return None



def get_SelectSelfMaxMin():
    try:
        url = "https://stq.niuguwang.com/zljl/MaxMin"
        headers = {'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('resultCode') == 0:
                return response_json.get('data')
            else:
                return None
        except:
            return None




def get_SelectSelf(start=None,end=None):
    try:
        url = "https://stq.niuguwang.com/zljl/zixuan?start={}&end={}".format(start,end)
        headers = {'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('resultCode') == 0:
                df_data = pd.DataFrame(response_json.get('data'))
                return df_data
            else:
                return None
        except:
            return None


if __name__ == '__main__':
    t11 = time.time()
    import ngwshare as ng


    data = ng.get_SearchData(start='2021-03-23 00:00:00',end='2021-03-23 23:59:59')
    print(data)

    data = ng.get_SelectSelfMaxMin()
    print(data)

    data = ng.get_SelectSelf(start=1, end=200)
    print(data)


    print(data.loc[0]['Codes'])

    print(time.time()-t11)














__author__ = 'wangjian'
import ngwshare as ng


# 获取所有 机器人id
data = ng.get_all_robots_info()
print(data)


# # # 停止某个机器人
# data = ng.stop_robot(robotId=101)
# print(data)


# # 获取机器人的持仓
# data = ng.get_robot_position(stgyAccount=34,symbol_exchange='cu2101.SHFE',posSide=2)
# print(data)
# # {'data': {'stgyPosId': 22, 'stgyAccount': 1, 'symbol': 'rb2101', 'exchange': 4, 'quantity': 1, 'forzen': 0, 'todayPositon': 0, 'todayForzen': 0, 'posSide': 1, 'margin': 5292.3, 'costPx': 3928.0, 'openCostPx': 3930.0, 'profit': 0.0, 'updateTime': '2020-11-30 10:32:16'}, 'error_no': 0, 'error_info': ''}
# data = ng.get_robot_position(stgyAccount=1,symbol_exchange='ag2101.SHFE',posSide=1)
# print(data)
# # {'data': None, 'error_no': 0, 'error_info': ''}


# # 获取机器人的上一日的equity
# data = ng.get_RobotLastEquity(robotId=40)
# print(data)




# # 机器人 下单
# data = ng.OmsContract_CreateOrder(stgyAccountId=34,stgySignalId=33,symbol_exchange='cu2101.SHFE',side='close_short',quantity=1,is_today=True)
# print(data)
# # {'data': 118, 'error_no': 0, 'error_info': ''}
# # {'data': 0, 'error_no': 1, 'error_info': '机器人已停止'}


# # # 机器人 查询订单状态
# data = ng.OmsContract_GetOrderStatus(stgyOrderId=299)
# print(data)
# # {'data': {'stgyOrderId': 118, 'stgyAccount': 1, 'stgySignalId': 12, 'orderId': '298054-SHFE_1000110_060031', 'symbol': 'ag2101', 'exchange': 4, 'orderSide': 66, 'offset': 1, 'quantity': 4, 'price': 1.0, 'filled': 4, 'orderTime': '2020-11-30 11:11:19', 'orderType': 1, 'tradeDate': '2020-11-30 00:00:00', 'updateTime': '2020-11-30 11:11:21', 'status': 5, 'note': '完全成交'}, 'error_no': 0, 'error_info': ''}


# # 机器人 撤单
# data = ng.OmsContract_CancelOrder(stgyAccountId=1, stgyOrderId=123)
# print(data)

# # {'error_no': 0, 'error_info': 'OK'}
# # {'error_no': 1, 'error_info': '无效的策略单id'}











__author__ = 'wangjian'

import ngwshare as ng

data = ng.get_USKline(symbol='dia',klineType='day',count=20)
print(data)

data = ng.get_USKline(symbol='dia',klineType='day',end='2021-02-01',count=20)
print(data)



# a = ng.get_USKline(symbol='dia',klineType='Week',count=20)
# print(a)
#
# a = ng.get_USKline(symbol='dia',klineType='Week',end='2021-02-03',count=20)
# print(a)










from ngwshare.utils.date_util import str2datetime
__author__ = 'wangjian'
from ngwshare.utils.http_util import get_ua
import requests
import traceback
import json
import pandas as pd
import datetime


# 根据日期返回交易日期
def ReturnTradingDate(DatetimeStr=None):
    dt_date = str(str2datetime(DatetimeStr))[:19]
    str_date = dt_date.replace('-', '').replace(':', '').replace(' ', '')
    try:
        url = "https://apigateway.inquantstudio.com/api/BasicData/GetTradeDate?time={}".format(str_date)
        headers = {'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('error_no') == 0:
                return str(str2datetime(response_json.get('data')))[:10]
            else:
                return None
        except:
            return None



# 返回历史主力合约
def get_HisMainContract(variety=None,start=None,end=None):
    start_ = str(str2datetime(start))[:19].replace('-', '').replace(':', '').replace(' ', '')
    end_ = str(str2datetime(end))[:19].replace('-', '').replace(':', '').replace(' ', '')
    body = {'varietyCode': variety,'begin': int(start_),'end': int(end_)}
    # print(json.dumps(body))
    try:
        url = "https://apigateway.inquantstudio.com/api/BasicData/GetHisMain"
        # url = "https://dev-apigateway.inquantstudio.com/api/BasicData/GetHisMain"
        headers = {'User-Agent': get_ua(),
                   "Content-Type": "application/json"}
        response = requests.post(url, data=json.dumps(body),headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('error_no') == 0:
                return pd.DataFrame(response_json.get('data'))
            else:
                return response_json.get('error_info')
        except:
            print(traceback.format_exc())



# 根据合约类别获取交易时间
def get_TradeDatetime(variety=None,start=None,end=None):
    start_ = str(str2datetime(start))[:19].replace('-', '').replace(':', '').replace(' ', '')
    end_ = str(str2datetime(end)+datetime.timedelta(days=1))[:19].replace('-', '').replace(':', '').replace(' ', '')
    body = {'varietyCode': variety,'begin': int(start_),'end': int(end_)}
    # print(json.dumps(body))
    try:
        url = "https://apigateway.inquantstudio.com/api/BasicData/GetOpenTimesByCode"
        # url = "https://dev-apigateway.inquantstudio.com/api/BasicData/GetOpenTimesByCode"
        headers = {'User-Agent': get_ua(),
                   "Content-Type": "application/json"}
        response = requests.post(url, data=json.dumps(body),headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('error_no') == 0:
                # return pd.DataFrame(response_json.get('data'))
                return response_json.get('data')
            else:
                return response_json.get('error_info')
        except:
            print(traceback.format_exc())


if __name__ == '__main__':
    import time
    import ngwshare as ng

    # trading_date = ReturnTradingDate(DatetimeStr='2021-03-26 01:09:00')
    # print(trading_date)

    # data = ng.get_HisMainContract(variety='v', start='2021-04-08', end='2021-04-09')
    # print(data)





    # a = ReturnTradingDate(DatetimeStr='20210410020000')
    # print(a)



    data = ng.get_TradeDatetime(variety='MA', start='2021-04-08', end='2021-05-13')
    print(data)

    # a = str(datetime.datetime.now())[:19]
    # b = str(datetime.datetime.now())[:19].replace('-','').replace(' ','').replace(':','')
    # print(a)
    # print(b)

    t11 = time.time()

    for b_e in data:
        begin = b_e.get('begin')
        end = b_e.get('end')
        # datetimeStr = '20210406101500'
        datetimeStr = str(datetime.datetime.now())[:19].replace('-', '').replace(' ', '').replace(':', '')
        if datetimeStr >= begin and datetimeStr < end:
            print('1111111111111')

        print(begin,end)

    print(time.time()-t11)



    # print(data.loc[1].begin)
    # print(type(data.loc[1].begin))
























import time
import json
import traceback
import requests
import datetime
import pandas as pd
import numpy as np
from ngwshare.conn_db.conn_sqlserver import conn_sqlserver_select
from ngwshare.conn_db.conn_mysql import conn_mysql_select
from ngwshare.utils.date_util import str2datetime, get_date_length, is_trading_day
# from ngwshare.utils.log_util import logger
from ngwshare.utils.http_util import get_ua
from ngwshare.constants import (
    MYSQL_HOST,
    MYSQL_PORT,
    MYSQL_DATABASE,
    MYSQL_USER,
    MYSQL_PASSWORD,
    HOST,
    PRE
)
from ngwshare.constants import (
    SQL_SERVER_HOST,
    SQL_SERVER_DATABASE,
    SQL_SERVER_USER,
    SQL_SERVER_PASSWORD
)


pd.set_option('display.max_rows',500)
pd.set_option('display.max_columns',500)
pd.set_option('display.width',1000)

host = HOST
pre = PRE
requests.DEFAULT_RETRIES = 10

def get_k_data(code=None, freq=None, start=None, end=None, bars=None):
    if bars:
        len = 200 if bars<100 else 500
        start =str(str2datetime(end)-datetime.timedelta(days=bars+len))
        # print(start,end)
    try:
        url = "https://{}/jy/dailyQuote?secuCodeMarket={}&startDate={}&endDate={}" \
            .format(host, code, start, end)
        # print(url)
        response = requests.get(url)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json["resultCode"] == 0:
            df_data = pd.DataFrame(response_json['data'])
            df_data.columns = ['code', 'date', 'open', 'high', 'low', 'close', 'preclose', 'volume', 'value']
            # df_data_ = df_data[['date', 'open', 'high', 'low', 'close', 'preclose','volume','value']]
            data_ = df_data.sort_values(by='date').reset_index(drop=True)
            if bars:
                return data_[-bars:].reset_index(drop=True)
            else:
                return data_
        else:
            return None


def get_stock_basic(code=None):
    try:
        url = "https://{}/jy/stockBasic?secuCodeMarket={}".format(host,code)
        response = requests.get(url)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json["resultCode"] == 0:
            return response_json['data']
        else:
            return None


def get_all_stock():
    try: # http://192.168.8.104:3389/api/stockAll
        url = "https://{}/jy/stockAll".format(host)
        # print(url)
        response = requests.get(url)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json["resultCode"] == 0:
            df_data = pd.DataFrame(response_json['data'])
            df_data.columns = ['code', 'name']
            return df_data
        else:
            return None


def get_performance(date):
    try:
        url = "https://{}/jy/performance?date={}".format(host,date)
        response = requests.get(url)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json["resultCode"] == 0:
            df_data = pd.DataFrame(response_json['data'])
            df_data.columns = ['code', 'name', 'date', 'total_MV', 'negotiable_MV', 'pre_close',
                               'open', 'high', 'low', 'close', 'trunover_volume', 'turnover_value']
            return df_data
        else:
            return None


def get_dIndicesForValuation(date):
    try:
        url = "https://{}/jy/dIndicesForValuation?date={}".format(host,date)
        response = requests.get(url)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json["resultCode"] == 0:
            df_data = pd.DataFrame(response_json['data'])
            df_data.columns = ['code', 'name', 'date', 'PELYR', 'PE', 'PB', 'PCF', 'PS', 'InsertTime']
            return df_data
        else:
            return None


def get_c_RR_ResearchReport(name=None,start=None,end=None):
    try:
        url = "https://{}/jy/c_RR_ResearchReport?name={}&startDate={}&endDate={}"\
            .format(host,name,start,end)
        response = requests.get(url)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json["resultCode"] == 0:
            df_data = pd.DataFrame(response_json['data'])
            return df_data
        else:
            return None


def get_specialTrade():
    try:
        url = "https://{}/jy/specialTrade".format(host)
        response = requests.get(url)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json["resultCode"] == 0:
            df_data = pd.DataFrame(response_json['data'])
            df_data.columns = ['code', 'name', 'date', 'type']
            return df_data
        else:
            return None



def get_financialData(table,stock,filed_list,start,end):
    if len(stock)>1:
        stock = tuple(stock)
    else:
        stock = str(tuple(stock)).replace(',','')
    try:
        url = "https://{}/jy/financialData?table={}&code={}&field={}&startDate={}&endDate={}"\
            .format(host,table,stock,filed_list,start,end)
        headers = {"Content-Type": "application/json",
                   'User-Agent': get_ua()}
        response = requests.get(url,headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json["resultCode"] == 0:
            df_data = pd.DataFrame(response_json['data'])
            return df_data
        else:
            return None



def get_financialDataPro(table,alterFiled,filed_list,start,end):
    try:
        url = "https://{}/jy/newestFinaIndex?table={}&alterField={}&field={}&startDate={}&endDate={}"\
            .format(host,table,alterFiled,filed_list,start,end)
        headers = {"Content-Type": "application/json",
                   'User-Agent': get_ua()}
        response = requests.get(url,headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json["resultCode"] == 0:
            df_data = pd.DataFrame(response_json['data'])
            return df_data
        else:
            return None


def get_fromCode(body=None):
    try:
        headers = {"Content-Type": "application/json",
                   'User-Agent': get_ua()}
        url = "https://{}/jy/fromCode".format(host)
        response = requests.post(url, data=json.dumps(body), headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        # print(response_json)
        if response_json.get("resultCode") == 0:
            if response_json.get('data'):
                df_data = pd.DataFrame(response_json['data'])
                columns_list = []
                field_list = body.get('field_list')
                if field_list:
                    columns_list = ['code', 'name']
                    columns_list.extend(field_list)
                df_data.columns = columns_list
                # 区分sz,sh
                if 'code_list' in body.keys():
                    df_data = df_data[df_data.code.isin(body['code_list'])]
                return df_data
            else:
                return 'no data exist.'
        else:
            return 'select error.'




def get_fromCompany(body=None):
    try:
        headers = {"Content-Type": "application/json",
                   'User-Agent': get_ua()}
        url = "https://{}/jy/fromCompany".format(host)
        response = requests.post(url, data=json.dumps(body), headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        # print(response_json)
        if response_json.get("resultCode") == 0:
            if response_json.get('data'):
                df_data = pd.DataFrame(response_json['data'])
                columns_list = []
                field_list = body.get('field_list')
                if field_list:
                    columns_list = ['code', 'name']
                    columns_list.extend(field_list)
                df_data.columns = columns_list
                if 'code_list' in body.keys():
                    df_data = df_data[df_data.code.isin(body['code_list'])]
                return df_data
            else:
                return 'no data exist.'
        else:
            return 'select error.'



def get_fromDate(body=None):
    try:
        headers = {"Content-Type": "application/json",
                   'User-Agent': get_ua()}
        url = "https://{}/jy/fromDate".format(host)
        response = requests.post(url, data=json.dumps(body), headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        # print(response_json)
        if response_json["resultCode"] == 0:
            if response_json.get('data'):
                df_data = pd.DataFrame(response_json['data'])
                columns_list = []
                field_list = body.get('field_list')
                if field_list:
                    columns_list.extend(field_list)
                df_data.columns = columns_list
                return df_data
            else:
                return 'no data exist.'
        else:
            return 'select error.'


def get_fromDateName(body=None):
    try:
        headers = {"Content-Type": "application/json",
                   'User-Agent': get_ua()}
        url = "https://{}/jy/fromDateName".format(host)
        response = requests.post(url, data=json.dumps(body), headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        # print(response_json)
        if response_json["resultCode"] == 0:
            if response_json.get('data'):
                df_data = pd.DataFrame(response_json['data'])
                columns_list = []
                field_list = body.get('field_list')
                if field_list:
                    columns_list.extend(field_list)
                df_data.columns = columns_list
                return df_data
            else:
                return 'no data exist.'
        else:
            return 'select error.'


def get_fromTable(body=None):
    try:
        headers = {"Content-Type": "application/json",
                   'User-Agent': get_ua()}
        url = "https://{}/jy/fromTable".format(host)
        response = requests.post(url, data=json.dumps(body), headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        # print(response_json)
        if response_json["resultCode"] == 0:
            if response_json.get('data'):
                df_data = pd.DataFrame(response_json['data'])
                columns_list = []
                field_list = body.get('field_list')
                if field_list:
                    columns_list.extend(field_list)
                df_data.columns = columns_list
                return df_data
            else:
                return 'no data exist.'
        else:
            return 'select error.'



def get_fromName(body=None):
    try:
        headers = {"Content-Type": "application/json",
                   'User-Agent': get_ua()}
        url = "https://{}/jy/fromName".format(host)
        response = requests.post(url, data=json.dumps(body), headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        # print(response_json)
        if response_json["resultCode"] == 0:
            if response_json.get('data'):
                df_data = pd.DataFrame(response_json['data'])
                columns_list = []
                field_list = body.get('field_list')
                if field_list:
                    columns_list.extend(field_list)
                df_data.columns = columns_list
                return df_data
            else:
                return 'no data exist.'
        else:
            return 'select error.'


# -------------------------------------------------------------------------------------

def get_type_from_freq(freq):
    if freq == '5m':
        return 1
    if freq == '15m':
        return 2
    if freq == '30m':
        return 3
    if freq == '60m':
        return 4
    if freq == 'd':
        return 5
    if freq == 'w':
        return 6
    if freq == 'mon':
        return 9
    if freq == '1m':
        return 11


def get_ex_from_adj(adj):
    if adj is None:
        return 0
    if adj == 'qfq':
        return 1
    if adj == 'hfq':
        return 2


def fixing_k_data(data, code, start, end):
    df_data = pd.DataFrame(data)
    df_data = df_data[['times', 'highp', 'openp', 'lowp', 'nowv', 'preclose', 'curvol', 'curvalue']]
    trading_day = [str(datetime.datetime.strptime(str(i), '%Y%m%d%H%M%S')) for i in df_data['times']]
    high = [round(float(i) / 100, 4) for i in df_data['highp']]
    open = [round(float(i) / 100, 4) for i in df_data['openp']]
    low = [round(float(i) / 100, 4) for i in df_data['lowp']]
    close = [round(float(i) / 100, 4) for i in df_data['nowv']]
    preclose = [round(float(i) / 100, 4) for i in df_data['preclose']]
    vol = [round(float(i), 4) for i in df_data['curvol']]

    data_dict = {}
    data_dict['code'] = [code for _ in range(len(trading_day))]
    data_dict['date'] = trading_day
    data_dict['open'] = open
    data_dict['high'] = high
    data_dict['low'] = low
    data_dict['close'] = close
    data_dict['preclose'] = preclose
    data_dict['volume'] = vol
    data_dict['value'] = df_data['curvalue']
    df_data_ = pd.DataFrame(data_dict)
    if len(start) == 10:
        start += ' 00:00:00'
    if len(end) == 10:
        end += ' 00:00:00'
    df_data_n = df_data_.loc[(df_data_["date"] >= start) & (df_data_["date"] <= end)]
    return df_data_n.sort_values(by='date').reset_index(drop=True)


def fixing_k_data_m(data, code):
    df_data = pd.DataFrame(data)
    df_data = df_data[['times', 'highp', 'openp', 'lowp', 'nowv', 'preclose', 'curvol', 'curvalue']]
    trading_day = [str(datetime.datetime.strptime(str(i), '%Y%m%d%H%M%S')) for i in df_data['times']]
    high = [round(float(i) / 100, 4) for i in df_data['highp']]
    open = [round(float(i) / 100, 4) for i in df_data['openp']]
    low = [round(float(i) / 100, 4) for i in df_data['lowp']]
    close = [round(float(i) / 100, 4) for i in df_data['nowv']]
    preclose = [round(float(i) / 100, 4) for i in df_data['preclose']]
    vol = [round(float(i), 4) for i in df_data['curvol']]

    data_dict = {}
    data_dict['code'] = [code for _ in range(len(trading_day))]
    data_dict['date'] = trading_day
    data_dict['open'] = open
    data_dict['high'] = high
    data_dict['low'] = low
    data_dict['close'] = close
    data_dict['preclose'] = preclose
    data_dict['volume'] = vol
    data_dict['value'] = df_data['curvalue']
    df_data_ = pd.DataFrame(data_dict)
    return df_data_.sort_values(by='date').reset_index(drop=True)


def get_stock_data_raw(code=None, freq=None, adj=None, start=None, end=None, bars=None):
    """
    :param code: 证券代码
    :param freq: 频率  1m  5m  15m  30m  60m  d   w   month
    :param adj: 复权类型  None：不复权（除权）   qfq：前复权    hfq：后复权
    :param start: 开始日期
    :param end: 结束日期
    :return:
    """
    # inner_code_dict
    if bars:
        len = 200 if bars<100 else 500
        start =str(str2datetime(end)-datetime.timedelta(days=bars+len))

    df_ = get_allStock()
    try:
        innerCode = df_[df_['code'] == code]['innercode'].tolist()[0]
    except:
        return pd.DataFrame()
    # print(innerCode)
    if innerCode is None:
        return pd.DataFrame()

    count = get_date_length(start, end)  # 开始日期到目前截至日期的len
    # print(start,end)
    end_ = str(str2datetime(end) + datetime.timedelta(days=1))
    start_ = end_.replace('-', '').replace(':', '').replace(' ', '')

    type = get_type_from_freq(freq)
    ex = get_ex_from_adj(adj)

    # url = ''
    if ex:
        url = "{}hq.niuguwang.com/aquote/quote/kline.ashx?code={}&type={}&start={}&count={}&ex={}" \
            .format(pre, innerCode, type, start_, count, ex)
    else:
        url = "{}hq.niuguwang.com/aquote/quote/kline.ashx?code={}&type={}&start={}&count={}" \
            .format(pre, innerCode, type, start_, count)
    # print(url)
    try:
        # t = time.time()
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        # print(response_json)
        # print(time.time()-t)
        if response_json:
            data = response_json['timedata']
            if data:
                # for i in data:
                #     print(i)
                df_data = fixing_k_data(data, code, start, end)
                # print(df_data)
                if bars:
                    return df_data[-bars:].reset_index(drop=True)
                else:
                    return df_data
            else:
                # print('休市.')
                return pd.DataFrame()
        else:
            return pd.DataFrame()


def get_stock_data_raw_m(code=None, freq=None, adj=None, start=None, end=None, bars=None):
    """
    :param code: 证券代码
    :param freq: 频率  1m  5m  15m  30m  60m  d   w   month
    :param adj: 复权类型  None：不复权（除权）   qfq：前复权    hfq：后复权
    :param start: 开始日期
    :param end: 结束日期
    :return:
    """
    # inner_code_dict
    df_ = get_allStock()
    try:
        innerCode = df_[df_['code'] == code]['innercode'].tolist()[0]
    except:
        return pd.DataFrame()
    # print(innerCode)
    if innerCode is None:
        return pd.DataFrame()

    type = get_type_from_freq(freq)
    ex = get_ex_from_adj(adj)
    url = "{}hq.niuguwang.com/aquote/quote/kline.ashx?code={}&type={}&count={}&ex={}" \
        .format(pre, innerCode, type, bars, ex)

    try:
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json:
            data = response_json['timedata']
            if data:
                df_data = fixing_k_data_m(data, code)
                return df_data
            else:
                return pd.DataFrame()
        else:
            return pd.DataFrame()


def get_stock_data(code=None, freq=None, adj=None, start=None, end=None, bars=None):
    delay_times = 5
    i = 0
    while i<delay_times:
        # print(i,delay_times)
        data = pd.DataFrame()
        if (end and bars) or (start and end):
            data = get_stock_data_raw(code=code, freq=freq, adj=adj, start=start, end=end, bars=bars)
        elif end is None and bars:
            data = get_stock_data_raw_m(code=code, freq=freq, adj=adj, start=start, end=end, bars=bars)
        else:
            return pd.DataFrame()

        if isinstance(data, pd.DataFrame):
            if not data.empty:
                return data

        i+=1
        time.sleep(0.01)
        continue
    return pd.DataFrame()

# -------------------------------------------------------------------------------------------
def get_stock_data_inner_raw(innercode=None, freq=None, adj=None, bars=None):
    """
    :param code: 证券代码
    :param freq: 频率  1m  5m  15m  30m  60m  d   w   month
    :param adj: 复权类型  None：不复权（除权）   qfq：前复权    hfq：后复权
    :param start: 开始日期
    :param end: 结束日期
    :return:
    """
    type = get_type_from_freq(freq)
    ex = get_ex_from_adj(adj)
    url = "{}hq.niuguwang.com/aquote/quote/kline.ashx?code={}&type={}&count={}&ex={}" \
        .format(pre, innercode, type, bars, ex)

    try:
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json:
            data = response_json['timedata']
            df_data = pd.DataFrame(data)
            return df_data
        else:
            return pd.DataFrame()


def get_stock_data_inner_rr(code=None, innercode=None, freq=None, adj=None, bars=None):
    """
    :param code: 证券代码
    :param freq: 频率  1m  5m  15m  30m  60m  d   w   month
    :param adj: 复权类型  None：不复权（除权）   qfq：前复权    hfq：后复权
    :param start: 开始日期
    :param end: 结束日期
    :return:
    """
    type = get_type_from_freq(freq)
    ex = get_ex_from_adj(adj)
    url = "{}hq.niuguwang.com/aquote/quote/kline.ashx?code={}&type={}&count={}&ex={}" \
        .format(pre, innercode, type, bars, ex)
    # print(url)
    try:
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json:
            data = response_json['timedata']
            if data:
                df_data = fixing_k_data_m(data, code)
                return df_data
            else:
                return pd.DataFrame()
        else:
            return pd.DataFrame()


def get_stock_data_inner(code=None, innercode=None, freq=None, adj=None, bars=None):
    delay_times = 5
    i = 0
    while i < delay_times:
        data = get_stock_data_inner_rr(code=code, innercode=innercode, freq=freq, adj=adj, bars=bars)
        if not data.empty:
            return data

        i += 1
        time.sleep(0.01)
        continue
    return pd.DataFrame()

# ------------------------------------------------------------------------------------------------------
def get_plate_data_inner_rr(code=None, innercode=None, freq=None, adj=None, bars=None):
    """
    :param code: 证券代码
    :param freq: 频率  1m  5m  15m  30m  60m  d   w   month
    :param adj: 复权类型  None：不复权（除权）   qfq：前复权    hfq：后复权
    :param start: 开始日期
    :param end: 结束日期
    :return:
    """
    type = get_type_from_freq(freq)
    ex = get_ex_from_adj(adj)
    url = "{}hq.niuguwang.com/aquote/plate/kline.ashx?code={}&type={}&count={}&ex={}" \
        .format(pre, innercode, type, bars, ex)
    # print(url)
    try:
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        # print(response_json)
        if response_json:
            data = response_json['timedata']
            if data:
                df_data = fixing_k_data_m(data, code)
                return df_data
            else:
                return pd.DataFrame()
        else:
            return pd.DataFrame()


def get_plate_data_inner_raw(innercode=None, freq=None, adj=None, bars=None):
    """
    :param code: 证券代码
    :param freq: 频率  1m  5m  15m  30m  60m  d   w   month
    :param adj: 复权类型  None：不复权（除权）   qfq：前复权    hfq：后复权
    :param start: 开始日期
    :param end: 结束日期
    :return:
    """
    type = get_type_from_freq(freq)
    ex = get_ex_from_adj(adj)
    url = "{}hq.niuguwang.com/aquote/plate/kline.ashx?code={}&type={}&count={}&ex={}" \
        .format(pre, innercode, type, bars, ex)
    # print(url)
    try:
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json:
            data = response_json['timedata']
            df_data = pd.DataFrame(data)
            return df_data
        else:
            return pd.DataFrame()


def get_plate_data_inner(code=None, innercode=None, freq=None, adj=None, bars=None):
    delay_times = 5
    i = 0
    while i < delay_times:
        data = get_plate_data_inner_rr(code=code, innercode=innercode, freq=freq, adj=adj, bars=bars)
        if not data.empty:
            return data

        i += 1
        time.sleep(0.01)
        continue
    return pd.DataFrame()

# -------------------------------------------------------------------------------------------
# 获取深度信息
def get_depth_raw(code=None):
    try:
        innerCode = int(code2nameInner(code.split('.')[0])[2])
        # df_ = get_allStock()
        # innerCode = df_[df_['code'] == code]['innercode'].tolist()[0]
    except:
        return None
    if innerCode is None:
        return None
    url = "{}hq.niuguwang.com/aquote/quotedata/detailfivedish.ashx?code={}".format(pre,innerCode)
    try:
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        # print(time.time()-t)
        if response_json:
            return fixing_depth(response_json,code)
        else:
            return None


def get_depth(code=None):
    delay_times = 5
    i = 0
    while i<delay_times:
        data = get_depth_raw(code=code)
        if data:
            return data
        
        i+=1
        time.sleep(0.01)
        continue


def fixing_depth(data,code):
    depth = {}
    depth['time'] = str(datetime.datetime.strptime(str(data['time']), '%Y%m%d%H%M%S'))
    depth['code'] = code
    depth['asks']=[
        [abs(float(data['ask1p'])),int(data['ask1v'])],
        [abs(float(data['ask2p'])),int(data['ask2v'])],
        [abs(float(data['ask3p'])),int(data['ask3v'])],
        [abs(float(data['ask4p'])),int(data['ask4v'])],
        [abs(float(data['ask5p'])),int(data['ask5v'])]
    ]
    depth['bids']=[
        [abs(float(data['bid1p'])),int(data['bid1v'])],
        [abs(float(data['bid2p'])),int(data['bid2v'])],
        [abs(float(data['bid3p'])),int(data['bid3v'])],
        [abs(float(data['bid4p'])),int(data['bid4v'])],
        [abs(float(data['bid5p'])),int(data['bid5v'])]
    ]
    return depth

# -------------------------------------------------------------------------------------------
def get_tick_raw(code=None):
    t11 = time.time()
    df_ = get_allStock()
    innerCode = df_[df_['code'] == code]['innercode'].tolist()[0]
    if innerCode is None:
        return None
    url = "{}hq.niuguwang.com/aquote/quotedata/stocktransaction.ashx?code={}".format(pre,innerCode)
    # print(url)
    try:
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        if response.content.decode():
            response_ = '[' + response.content.decode().split('[')[1].split(']')[0] + ']'
            response_json = json.loads(response_)
            return fixing_tick(response_json)
        else:
            return pd.DataFrame()


def get_tick(code=None):
    delay_times = 5
    i = 0
    while i<delay_times:
        data = get_tick_raw(code=code)
        if isinstance(data, pd.DataFrame):
            if not data.empty:
                return data

        i+=1
        time.sleep(0.01)
        continue
    return pd.DataFrame()


def fixing_tick(data):
    df_data = pd.DataFrame(data)
    # print(df_data)
    trading_day = [str(datetime.datetime.strptime(str(i), '%Y%m%d%H%M%S')) for i in df_data['time']]
    df_data['time'] = trading_day
    return df_data


def get_allStock():
    sql_info = {
        'host':MYSQL_HOST,
        'port': MYSQL_PORT,
        'database': MYSQL_DATABASE,
        'user': MYSQL_USER,
        'password': MYSQL_PASSWORD,
    }
    try:
        sql = """select * from innerCodeMap;"""
        data = conn_mysql_select(sql,sql_info)
        if data:
            df_data = pd.DataFrame(data)
            df_data.columns = ['id', 'innercode', 'code', 'name', 'market','boardname','stocktype','insert_time','update_time']
            # df_data.columns = ['id', 'innercode', 'code', 'name', 'insert_time']
            # df_data.columns = ['id', 'innercode', 'code', 'name']
            return df_data
    except Exception:
        print(traceback.format_exc())


def get_allOnlyStock():
    sql_info = {
        'host':MYSQL_HOST,
        'port': MYSQL_PORT,
        'database': MYSQL_DATABASE,
        'user': MYSQL_USER,
        'password': MYSQL_PASSWORD,
    }
    try:
        sql = """select * from innerCodeMap where stocktype=1;"""
        data = conn_mysql_select(sql,sql_info)
        if data:
            df_data = pd.DataFrame(data)
            df_data.columns = ['id', 'innercode', 'code', 'name', 'market','boardname','stocktype','insert_time','update_time']
            # df_data.columns = ['id', 'innercode', 'code', 'name', 'insert_time']
            # df_data.columns = ['id', 'innercode', 'code', 'name']
            return df_data
    except Exception:
        print(traceback.format_exc())

def get_allStock2(date=None):
    # date_ = date.replace('-','')
    try:
        # 1 前复权
        url = "{}hq.niuguwang.com/aquote/quote/daykline_allstock.ashx?ex=0&date={}".format(pre, date)
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json:
            return response_json['dayklines']
        else:
            return None

def inner2code(inner):
    try:
        url = "{}://pub.niuguwang.com/stockpub/stock/astockinfo.ashx?code={}".format(pre.split(':')[0],inner)
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json:
            market = ''
            if response_json.get('market') == 1:
                market = 'SH'
            elif response_json.get('market') == 2:
                market = 'SZ'
            else:
                return None
            return response_json['symbol'] + '.' + market
        else:
            return None


def code2nameInner(code):
    try:
        url = "{}://pub.niuguwang.com/stockpub/stock/astockinfo.ashx?symbol={}".format(pre.split(':')[0],code)
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        # print(response_json)
        if response_json:
            symbol = response_json['symbol']
            name = response_json['stockname']
            innercode = response_json['innercode']
            return [symbol,name,innercode]
        else:
            return None

# -------------------------------------------------------------------------------------------
def get_price_raw(codes=None):
    codes_list = []
    for code in codes:
        if isinstance(code,str):
            if len(code) == 9:
                code_s = code.split('.')[1].lower() + code.split('.')[0]
                codes_list.append(code_s)
            else:
                codes_list.append(code)
        if isinstance(code,int):
            codes_list.append(str(code))
    # codes_list = [str(i).split('.')[1].lower() + i.split('.')[0] for i in codes]
    codes_ = ','.join(codes_list)
    url = "{}hq.niuguwang.com/aquote/quotedata/batchstockprice.ashx?codes={}".format(pre,codes_)
    # print(url)
    try:
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        if response.content.decode():
            response_json = json.loads(response.content.decode())
            df_data = pd.DataFrame(response_json.get('list'))
            df_data['code'] = codes
            return df_data
        else:
            return pd.DataFrame()


def get_price(codes=None):
    delay_times = 5
    i = 0
    while i<delay_times:
        data = get_price_raw(codes=codes)
        if isinstance(data, pd.DataFrame):
            if not data.empty:
                return data

        i+=1
        time.sleep(0.01)
        continue
    return pd.DataFrame()

# ---------------------------------------------------------------------------------------------------
def get_allPlate():
    sql_info = {
        'host':SQL_SERVER_HOST,
        'database': SQL_SERVER_DATABASE,
        'user': SQL_SERVER_USER,
        'password': SQL_SERVER_PASSWORD,
    }
    sql = """select innerCode,Code,Name,PlateType,PlateId,SecuCategoryCodeII from PlateInfo;"""
    data = np.array(conn_sqlserver_select(sql,sql_info))
    df_data = pd.DataFrame(data,columns=['innercode', 'code', 'name', 'plate_type', 'plate_id', 'SecuCategoryCodeII'])
    df_data['stocktype'] = [2 for _ in range(len(df_data))]

    # plate_innerCode_list = df_data['innercode'].values
    # plate_code_list = df_data['code'].values

    return df_data


# ---------------------------------------------------------------------------------------------------------
def get_trans_raw(codes=None):
    codes_list = []
    for code in codes:
        if isinstance(code,str):
            if len(code) == 9:
                code_s = code.split('.')[1].lower() + code.split('.')[0]
                codes_list.append(code_s)
            else:
                codes_list.append(code)
        if isinstance(code,int):
            codes_list.append(str(code))
    # codes_list = [str(i).split('.')[1].lower() + i.split('.')[0] for i in codes]

    codes_ = ','.join(codes_list)
    url = "{}hq.niuguwang.com/aquote/quotedata/batchstockprice.ashx?codes={}&allpx=1&trans=1".format(pre,codes_)
    print(url)
    try:
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        if response.content.decode():
            response_json = json.loads(response.content.decode())
            df_data = pd.DataFrame(response_json.get('list'))
            df_data['code'] = codes
            return df_data
        else:
            return None


def get_trans(codes=None):
    delay_times = 5
    i = 0
    while i<delay_times:
        data = get_trans_raw(codes=codes)
        if isinstance(data, pd.DataFrame):
            if not data.empty:
                return data

        i+=1
        time.sleep(0.01)
        continue
# ---------------------------------------------------------------------------------------------------------
def get_zjlx():
    url = "http://push2.eastmoney.com/api/qt/ulist.np/get?fltt=2&secids=1.000001,0.399001&" \
          "fields=f62,f184,f66,f69,f72,f75,f78,f81,f84,f87,f64,f65,f70,f71,f76,f77,f82,f83,f164,f166,f168,f170,f172,f252,f253,f254,f255,f256,f124,f6,f278,f279,f280,f281,f282&" \
          "ut=b2884a393a59ad64002292a3e90d46a5&cb=jQuery18303224400345741254_1596166834140&_={}".format(round(time.time()*1000))
    # print(url)
    try:
        headers = {
            'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        logger.info(traceback.format_exc())
    else:
        if response.content.decode():
            response_str = response.content.decode().split('(')[1].replace(')','').replace(';','')
            response_json = json.loads(response_str)

            zhuliJLR = 0
            chaodadanJLR = 0
            dadanJLR = 0
            zhongdanJLR = 0
            xiaodanJLR = 0
            for ss in response_json['data']['diff']:
                zhuliJLR += float(ss['f62'])
                chaodadanJLR += float(ss['f66'])
                dadanJLR += float(ss['f72'])
                zhongdanJLR += float(ss['f78'])
                xiaodanJLR += float(ss['f84'])
            return [zhuliJLR, chaodadanJLR, dadanJLR, zhongdanJLR, xiaodanJLR]
        else:
            return None



# -----------------------------------------------------------------------------------------------------------
def return_last_trading_day(date=None):
    if date:
        now_date = datetime.datetime.strptime(date, '%Y-%m-%d')
    else:
        now_date = datetime.datetime.now()

    while True:
        l_date = now_date - datetime.timedelta(days=1)
        if is_trading_day(l_date):
            return l_date
        else:
            now_date = l_date
            continue



if __name__ == '__main__':
    import time
    from pprint import pprint

    # start_ = time.time()
    #
    # df = get_allStock()
    # print(df)
    #
    # innercode = df[df.code == '600747.SH']['innercode'].values[0]
    # name = df[df.code == '600747.SH']['name'].values[0]
    # print(innercode)
    # print(name)
    #
    #
    # print(time.time() - start_)
    #
    #
    # start_ = time.time()
    #
    # df = get_allPlate()
    # print(df)
    #
    # print(time.time() - start_)




    # start_ = time.time()
    #
    # data = get_plate_data_inner(code='882178', innercode=2000502, freq='d', adj='qfq', bars=300)
    # print(data)
    #
    # print(time.time() - start_)
    #
    #
    #
    #
    # start_ = time.time()
    #
    # data = get_plate_data_inner_raw(innercode=2000502, freq='d', adj='qfq', bars=300)
    # print(data)
    #
    # print(time.time() - start_)




    # start_ = time.time()
    #
    # data = get_stock_data_inner(code='000688.SH', innercode=2326, freq='d', adj='qfq', bars=300)
    # print(data)
    #
    # print(time.time() - start_)
    #
    #
    # start_ = time.time()
    #
    # data = get_stock_data_inner(code='399106.SZ', innercode=2194, freq='d', adj='qfq', bars=300)
    # print(data)
    #
    # print(time.time() - start_)




    # df = get_performance('2020-05-25')
    # print(df)

    # df = get_all_stock()
    # print(df)

    # df = get_dIndicesForValuation('2020-05-25')
    # print(df)

    # df = get_c_RR_ResearchReport(name='国泰君安', start='2020-05-10', end='2020-05-12')
    # print(df)

    # df = get_stock_basic(code='000058.SH')
    # pprint(df)

    # df = get_specialTrade()
    # print(df)

    # df = hk_hold('20190625')
    # print(df)

    # date = get_k_data(code='399006.SZ', freq='d', end='2020-07-05', bars=300)
    # print(date)
    # date = get_stock_data(code='399006.SZ', freq='d', adj='qfq',end='2020-07-05', bars=300)
    # print(date)

    # df = get_k_data(code='603106.SH', freq='d', start='2019-05-27', end='2020-07-08')
    # print(df)


    # data = get_stock_data(code='002982.SZ', freq='d', adj='qfq', start='2019-05-27', end='2020-07-08')
    # print(data)
    # 90762

    # # 分钟
    # data = get_stock_data(code='399006.SZ', freq='1m', adj='qfq', bars=300)
    # print(data)
    # data = get_stock_data(code='399006.SZ', freq='5m', adj='qfq', bars=300)
    # print(data)
    # data = get_stock_data(code='399006.SZ', freq='15m', adj='qfq', bars=300)
    # print(data)
    # data = get_stock_data(code='399006.SZ', freq='30m', adj='qfq', bars=300)
    # print(data)
    # data = get_stock_data(code='399006.SZ', freq='60m', adj='qfq', bars=300)
    # print(data)





    # data = get_stock_data(code='399006.SZ', freq='d', adj='qfq',end='2020-07-05', bars=300)
    # print(data)
    # data = get_stock_data(code='399006.SZ', freq='d', adj='qfq', start='2019-05-27', end='2020-07-08')
    # print(data)



    # data = get_stock_data(code='399006.SZ', freq='w', adj='qfq', bars=30)
    # print(data)
    # data = get_stock_data(code='399006.SZ', freq='mon', adj='qfq', bars=30)
    # print(data)


# code          trading_day   open   high    low  close  preclose          vol       value
#          code                 date   open   high    low  close  preclose       volume       value
#           code                 date   open   high    low  close  preclose       volume         value

    # # code
    # code_list = ["000858.SZ","600722.SH","000895.SZ","600006.SH"]
    # # table = 'QT_DailyQuote'
    # # field_list = ["TradingDay", "PrevClosePrice", "OpenPrice", "HighPrice", "LowPrice"]
    # table = 'LC_SHSZHSCHoldings'
    # field_list = ["SHSZHSCode", "SecuAbbr", "SharesHolding", "Holdratio", "InsertTime"]
    # body = {
    #     "table": table,
    #     "code_list": code_list,
    #     # "all_code": True,
    #     "field_list": field_list,
    #     # "alterField": "TradingDay",
    #     "alterField": "EndDate",
    #     "startDate": "2020-01-23",
    #     "endDate": "2020-05-26"
    # }
    # data = get_fromCode(body)
    # print(data)


    # company
    # code_list = ["000858.SZ", "600722.SH", "000895.SZ", "600006.SH"]
    # table = 'LC_MainQuarterData'
    # field_list = ["EndDate", "BasicEPS", "OperatingReenue", "CashEquialents", "TotalShares"]
    # body = {
    #     "table": table,
    #     "code_list": code_list,
    #     # "all_code": True,
    #     "field_list": field_list,
    #     "alterField": "EndDate",
    #     "startDate": "2019-01-01",
    #     "endDate": "2020-05-26"
    # }
    # data = get_fromCompany(body)
    # print(data)
    #
    #
    #
    # # date
    # table = 'QT_SHSZHSCTradingDay'
    # field_list = ["EndDate", "TradingType", "IfWeekEnd", "IfYearEnd", "UpdateTime","InfoSource"]
    # body = {
    #     "table": table,
    #     "field_list": field_list,
    #     "alterField": "EndDate",
    #     "startDate": "2020-01-01",
    #     "endDate": "2020-05-26"
    # }
    # data = get_fromDate(body)
    # pprint(data)









    # depth = get_depth(code='000028.SZ')
    # pprint(depth)
    # print(depth['asks'][1][0])
    # print(depth['asks'][0][0])
    #
    #
    # tick = get_tick(code='000028.SZ')
    # print(tick)
    #
    #
    #
    # table = 'C_RR_ResearchReport'
    # field_list = ["OrgName", "OrgNameDisc", "AreaCode", "Author", "WritingDate", "InsertTime"]
    # name = ['国泰君安', '中信证券']
    #
    # body = {
    #     "table": table,
    #     "field_list": field_list,
    #     "alterFieldName": "OrgNameDisc",
    #     "name":name,
    #     "alterFieldDate": "InfoPublDate",
    #     "startDate": "2020-05-01",
    #     "endDate": "2020-07-07"
    # }
    # data = get_fromDateName(body=body)
    # print(data)



    # price = get_price(codes=['000001.SZ','600000.SH','000028.SZ',"000858.SZ", "600722.SH", "000895.SZ", "600006.SH"])
    # print(price)

    a = code2nameInner('300033')
    print(a)
    # print(time.time()-start_)






import requests
import json
import time
import traceback
from ngwshare.utils.date_util import str2datetime
from ngwshare.utils.http_util import get_ua
import pandas as pd
import datetime

def get_allStock():
    try:
        headers = {'User-Agent': get_ua()}
        url = "https://stq.niuguwang.com/jy/innercode"
        # print(url)
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        response_json = json.loads(response.content.decode())
        if response_json["resultCode"] == 0:
            df_data = pd.DataFrame(response_json['data'])
            df_data.columns = ['innercode', 'code', 'name', 'market', 'boardname', 'stocktype', 'insert_time',
                               'update_time']
            return df_data
        else:
            return None

def getRZRQStock(start=None,end=None,stock_list=None):
    if stock_list:
        all_df = get_allStock()
        innercode_list = all_df[all_df['code'].isin(stock_list)]['innercode'].tolist()
    else:
        innercode_list = []
    body = {
        'start':start,
        'end': end,
        'innercode_list': innercode_list,
    }
    url = 'https://stq.niuguwang.com/jydata/rzrqstock'
    try:
        headers = {"Content-Type": "application/json",'User-Agent':get_ua()}
        response = requests.post(url,data=json.dumps(body), headers=headers).content.decode()
        response_json = json.loads(response)
        # print(response_json)
        if response_json['resultCode'] == 0:
            return pd.DataFrame(response_json['data'])
        else:
            return response_json['data']
    except Exception:
        print(traceback.format_exc())



if __name__ == '__main__':
    import ngwshare as ng
    # 获取个股融资融券
    data = ng.getRZRQStock(start='2021-06-14',end='2021-06-15',stock_list=['000001.SZ','600016.SH','300383.SZ'])
    print(data)




import datetime

import ngwshare as ng
import time
import pandas as pd
# pd.set_option('display.height',1000)
pd.set_option('display.max_rows',5000)
pd.set_option('display.max_columns',5000)
pd.set_option('display.width',10000)



# data = ng.get_hisBar(symbol='rb2011',exchange='SHFE',freq='1m',start='2020-09-01',end='2020-10-20')
# print(data)



# data = ng.get_hisBar(symbol='agM',exchange='SHFE',freq='1m',start='2021-03-26',end='2021-03-30')
# print(data)



# data = ng.get_hisBar(symbol='rbM',exchange='SHFE',freq='1m',start='2019-01-01',end='2019-10-01')
# print(data)


# data = ng.get_hisBar(symbol='rb2011',exchange='SHFE',freq='15m',start='2019-10-01',end='2020-10-20')
# print(data)


# data = ng.get_hisBar(symbol='rb2011',exchange='SHFE',freq='15m',start='2019-10-01',end='2020-10-20')
# print(data)


# data = ng.get_hisBar(symbol='i2011',exchange='DCE',freq='1m',start='2019-10-01',end='2020-10-20')
# print(data)

# data = ng.get_hisBar(symbol='cM',exchange='DCE',freq='1d',start='2020-10-01',end='2020-10-20')
# print(data)



# data = ng.get_hisBar(symbol='ZC012',exchange='CZCE',freq='1d',start='2020-10-01',end='2020-10-20')
# print(data)


# data = ng.get_hisBar(symbol='rb2101',exchange='SHFE',freq='1m',start='2020-10-20',end='2020-10-21')
# print(data)

# close_price = data.loc[(data['time'] > 20201020222600)]
# print(close_price)

# close_price = data.loc[(data['time'] > 20201020222600)].iloc[0]['open']
# print(close_price)


# data = ng.get_hisBar(symbol='ag2101',exchange='SHFE',freq='1m',start='2020-10-29 09:00:00',end='2020-10-30 15:00:00')
# print(data)
#
# data = ng.get_hisBar(symbol='hcM',exchange='SHFE',freq='1m',start='2021-02-21 09:00:00',end='2021-02-25 15:00:00')
# print(data)

# data = ng.get_hisBar(symbol='ag2101',exchange='SHFE',freq='5m',start='2020-10-29 09:00:00',end='2020-10-30 15:00:00')
# print(data)
# data = ng.get_hisBar(symbol='ag2101',exchange='SHFE',freq='15m',start='2020-10-29 09:00:00',end='2020-10-30 15:00:00')
# print(data)
# data = ng.get_hisBar(symbol='ag2101',exchange='SHFE',freq='30m',start='2020-10-29 09:00:00',end='2020-10-30 15:00:00')
# print(data)
# data = ng.get_hisBar(symbol='ag2101',exchange='SHFE',freq='60m',start='2020-10-29 09:00:00',end='2020-10-30 15:00:00')
# print(data)


# data = ng.get_hisBar(symbol='ag2101',exchange='SHFE',freq='1d',start='2020-10-28 09:00:00',end='2020-10-30 15:00:00')
# print(data)

# data = ng.get_hisBar(symbol='ag2105',exchange='SHFE',freq='10s',start='2020-10-28 09:00:00',end='2020-10-30 15:00:00')
# print(data)


# data = ng.get_hisBar(symbol='ag2105',exchange='SHFE',freq='d', end='2021-01-01', count=500)
# print(data)

# data = ng.get_hisBar(symbol='agM',exchange='SHFE',freq='10s', count=500)
# print(data)

# data = ng.get_hisBar(symbol='p2109',exchange='DCE',freq='10s', start='2021-04-20', end='2021-04-21')
# print(data)

# data = ng.contract_depth(symbol='rb2101',exchange='SHFE')
# print(data)


# # 获取某一时刻的全部价格(time不传为目前时间)
# data = ng.all_contract_price(freq='1d',time='2020-11-19')
# print(data)
# data = ng.all_contract_price(freq='1m')
# print(data)

# # -----------------------------------------------------------------------------------------------------------
# t1 = time.time()

# # Tick

# data = ng.get_hisTick(symbol='rb2104',exchange='SHFE',count=1)
# print(data)


# data = ng.get_hisTick(symbol='rb2103',exchange='SHFE',start='2021-02-01 13:30:00',end='2021-02-02 14:30:00')
# print(data)


# data = ng.get_hisTick(symbol='rb2103',exchange='SHFE',end='2021-02-02 14:30:00',count=10)
# print(data)


# # 获取用户持仓
# import hashlib
# def get_sign1(start,end):
#     m = hashlib.md5()
#     m.update('inquantRisk:{}{}'.format(start, end).encode('utf-8'))
#     return m.hexdigest().upper()
#
# start = '2020-11-10'
# end = '2020-11-11'
# sign = get_sign1(start,end)
# print(sign)
# data = ng.contract_position_users(start=start,end=end,sign=sign)
# print(data)



# def get_sign2(start,end,code):
#     m = hashlib.md5()
#     m.update('inquantRiskContract:{}{}{}'.format(start, end, code).encode('utf-8'))
#     return m.hexdigest().upper()
# # 获取用户持仓
# code = 'a1909'
# start = '2020-11-16'
# end = '2020-11-20'
# sign = get_sign2(start,end,code)
# print(sign)
# data = ng.contract_all_position_users(start=start,end=end,code=code,sign=sign)
# print(data)



# # # 获取所有现货code
# # data = ng.get_all_spot()
# # print(data)

# # # 获取现货价格
# # data = ng.get_spot_price(spotCode='cuXH',start='2020-11-10',end='2020-11-11')
# # print(data)


# # 获取合约分类
# data = ng.get_contract_varieties(type=4)
# print(data)
# # type（3：中金所，4：上期所，5：大商所，6：郑商所 ,11:主力合约 12：夜盘合约,13:环球,101:主连合约


# # 获取买卖情况
# data = ng.get_TradeVolumeRanking(vid=24,start='2020-01-13',end='2020-02-10')
# print(data)




# # 获取所有合约
# data = ng.get_all_contract()
# print(data)


# # 获取单个合约信息
# data = ng.get_contract_detail(symbol='rb2105',exchange='SHFE')
# print(data)

# # 获取单个合约信息
# data = ng.get_contract_detail(symbol='ag2101',exchange='SHFE')
# print(data)

# 获取单个合约信息
# data = ng.get_contract_detail(symbol='i2101',exchange='DCE')
# print(data)
# # 获取单个合约信息
# data = ng.get_contract_detail(symbol='au2012',exchange='SHFE')
# print(data)




# # 获取主力合约
# data = ng.get_main_contract(variety_code='v')
# print(data)
# print(data['symbol'])

# # 获取历史主力合约
# data=ng.get_HisMainContract(variety='v', start='2021-01-01', end='2021-06-09')
# print(data)


# universe = 'cM.DCE'
# variety = universe.split(".")[0][:-1]
# market = universe.split(".")[1]
# print(variety)
# main_symbol = ng.get_main_contract(variety_code=variety)["symbol"]+"."+market
# universe = main_symbol
#
# print(universe)


# # 获取一个时间段的 交易时间
# data = ng.get_contract_openTime(start='2021-04-01',end='2021-04-20')
# print(data)
# data['begin'] = [str(datetime.datetime.strptime(i, '%Y%m%d%H%M%S'))[:19] for i in data['begin'].tolist()]
# data['end'] = [str(datetime.datetime.strptime(i, '%Y%m%d%H%M%S'))[:19] for i in data['end'].tolist()]
# print(data)

# print(time.time()-t1)
# # -----------------------------------------------------------------------------------------------------------



# # 获取所有品种variety
# data = ng.get_all_varieties()
# print(data)




# a = data.loc[data['varietyCode']=='cs']
# print(a)
#
#
# varietyId = a['id'].tolist()[0]
# print(varietyId,type(varietyId))
#
# lots = a['lots'].tolist()[0]
# print(lots,type(lots))


# # 获取乘数、保证金比率
# all_margin_ratios = ng.get_all_margin_ratios()
# print(all_margin_ratios)
# data = all_margin_ratios[all_margin_ratios.varietyID==10]
# print(data)
# data = all_margin_ratios[(all_margin_ratios.varietyID==23) & (all_margin_ratios['code']=='!')]
# print(data)
# data = all_margin_ratios[(all_margin_ratios.varietyID==23) & (all_margin_ratios['code']=='!')]['ratio'].tolist()[-1]
# print(data)



# # 获取手续费率
# ratio_data = ng.get_all_commission_raw()
# print(ratio_data)
# data = ratio_data[ratio_data.varietyID==23]
# print(data)


# a = all_margin_ratios.loc[all_margin_ratios['varietyID']==varietyId]['ratio']
# print(a)
#
# b = a.tolist()[-1]
# print(b)



# t1 = time.time()
#
#
# universe = 'buM.SHFE'
# variety = universe.split(".")[0][:-1]
# market = universe.split(".")[1]
# data = ng.get_main_contract(variety_code=variety)
# print(data)
# main_symbol = data["symbol"]+"."+market
# print([main_symbol])
#
#
#
# print(time.time()-t1)


data = ng.get_spot_price_by_variety('rb', datetime.datetime(2021, 5, 21), datetime.datetime(2021, 6, 21))
print(data)

contract = ng.get_contract_detail('rb2110', 'SHFE')
print(contract)

ranks = ng.get_member_rank('rb', datetime.datetime(2021, 5, 21), datetime.datetime(2021, 6, 21), 0)
print(ranks)












import datetime
import ngwshare as ng
import time
import pandas as pd
# pd.set_option('display.height',1000)
from ngwshare.utils.date_util import str2datetime

pd.set_option('display.max_rows',500)
pd.set_option('display.max_columns',500)
pd.set_option('display.width',1000)

t1 = time.time()



# # # 获取K线
# df = ng.get_k_data(code='000058.SH',freq='d',start='2020-01-01',end='2020-05-15')
# print(df)
#
# df = ng.get_k_data(code='001914.SZ', freq='d',start='2019-01-01', end='2020-07-01')
# print(df)



# df = ng.get_k_data(code='000058.SH',freq='d',enfd='2020-05-15',bars=30)
# print(df)
#
#
#
#
# # 获取股票基本信息
# df = ng.get_stock_basic(code='000058.SH')
# print(df)

# 000760.SZ
# # 获取所有股票代码
# df = ng.get_all_stock()
# print(df['code'].tolist())
# print(len(df['code'].tolist()))


#
# 总市值、流通市值等
# df = ng.get_performance('2020-05-25')
# print(df)

#
# # 市盈率、市净率等(加入InsertTime)
# df = ng.get_dIndicesForValuation('2020-05-25')
# print(df)
#
# # 研报
# df = ng.get_c_RR_ResearchReport(name='国泰君安', start='2020-05-10', end='2020-05-12')
# print(df)
#
# # ST
# df = ng.get_specialTrade()
# print(df)
#
#
# # 陆股通
# df = ng.hk_hold('20190625')
# print(df)



# # 根据表，字段 获取财务数据
# table = 'LC_MainQuarterData'
# stock_tuple = ['000007.SZ','600722.SH','000501.SZ']
# filed_list = ['EndDate','BasicEPS','DilutedEPS']
# start = '2010-01-01'
# end = '2020-05-15'
# data = ng.get_financialData(table, stock_tuple, filed_list, start, end)
# print(data)
#
#
# table = 'LC_MainDataNew'
# stock_tuple = ['600064.SH']
# filed_list = ['BasicEPS']
# start = '2010-01-01'
# end = '2020-05-15'
# data = ng.get_financialData(table, stock_tuple, filed_list, start, end)
# print(data)


# table = 'LC_MainDataNew'
# stock_tuple = ['300033.SZ']
# filed_list = ['InfoPublDate','EndDate','NetProfit','BulletinType','BulletinType']
# start = '2018-05-15'
# end = '2020-04-15'
# df = ng.get_financialData(table, stock_tuple, filed_list, start, end)
# print(df)


# 通过指定表 指定日期类型字段 筛选
# table = 'LC_NewestFinaIndex'
# alterField = 'AdjustDate'
# filed_list = ['ShareCapitalAftereAdjust','RetainedProfitBeforeAdjust','EPS']
# start = '2020-01-15'
# end = '2020-05-15'
# df = ng.get_financialDataPro(table, alterField, filed_list, start, end)
# print(df)




# # 根据companyCode 查询表
# table = 'LC_NewestFinaIndex'
# alterField = 'AdjustDate'
# filed_list = ['EPS','EPSTTM']
# start = '2020-01-15'
# end = '2020-05-15'
# df = ng.get_fromCompany(table, alterField, filed_list, start, end)
# print(df)



# code_list = ["000858.SZ", "600722.SH", "000895.SZ", "600006.SH"]
# table = 'QT_DailyQuote'
# field_list = ["TradingDay", "PrevClosePrice", "OpenPrice", "HighPrice", "LowPrice"]
# body = {
#     "table": table,
#     "code_list": code_list,
#     # "all_code": True,
#     "field_list": field_list,
#     "alterField": "TradingDay",
#     # "alterField": "EndDate",
#     "startDate": "2018-05-23",
#     "endDate": "2020-05-26"
# }
# data = ng.get_fromCode(body)
# print(data)






# select InnerCode,
# RightRegDate, -- 股权登记日
# ExDiviDate, -- 除权除息日
# BonusShareListDate,-- 股息到帐日期/红利发放日
# ToAccountDate, -- 最后交易日
#
# BonusShareRatio, -- 送股比例(10送X)
# TranAddShareRaio, -- 转增股比例(10转增X)
# CashDiviRMB, -- 派现(含税/人民币元)
# ActualCashDiviRMB, -- 	实派(税后/人民币元)
#
# BonusSHRatioAdjusted, -- 送股比例(10送X)(计算除权价用)
# TranAddRatioAdjusted, -- 转增比例(10转增X)(计算除权价用)
# CashDiviRMBAdjusted -- 	派现(含税10派X元)(计算除权价用)
# from LC_Dividend where RightRegDate>'2020-01-01';


#
# t1 = time.time()
#
# code_list = ["000403.SZ", "300765.SZ", "600340.SH"]
# table = 'LC_Dividend'
# field_list = ["RightRegDate", "ExDiviDate", "BonusShareListDate", "ToAccountDate",
#               "BonusShareRatio","TranAddShareRaio","CashDiviRMB","ActualCashDiviRMB",
#               "BonusSHRatioAdjusted","TranAddRatioAdjusted","CashDiviRMBAdjusted"
#               ]
# body = {
#     "table": table,
#     "code_list": code_list,
#     # "all_code": True,
#     "field_list": field_list,
#     "alterField": "RightRegDate",
#     # "alterField": "EndDate",
#     "startDate": "1995-01-01",
#     "endDate": "2030-07-27"
# }
# data = ng.get_fromCode(body)
# print(data)
#
#
#
# print(time.time()-t1)




# body = {
#     "table": 'SecuMain',
#     "field_list": ['SecuCode', 'SecuAbbr', 'SecuMarket', 'ListedSector', 'ListedState'],
#     "alterFieldName": 'SecuCategory',
#     "name": [1],
# }
# dfgb_all_code = ng.get_fromName(body)
# print(dfgb_all_code)




# # company
# code_list = ["000858.SZ", "600722.SH", "000895.SZ", "600006.SH"]
# table = 'LC_MainQuarterData'
# field_list = ["EndDate", "BasicEPS", "OperatingReenue", "CashEquialents", "TotalShares"]
# body = {
#     "table": table,
#     "code_list": code_list,
#     # "all_code": True,
#     "field_list": field_list,
#     "alterField": "EndDate",
#     "startDate": "2019-01-01",
#     "endDate": "2020-05-26"
# }
# data = ng.get_fromCompany(body)
# print(data)
#
# # date
# table = 'QT_SHSZHSCTradingDay'
# field_list = ["EndDate", "TradingType", "IfWeekEnd", "IfYearEnd", "UpdateTime", "InfoSource"]
# body = {
#     "table": table,
#     "field_list": field_list,
#     "alterField": "EndDate",
#     "startDate": "2020-01-01",
#     "endDate": "2020-05-26"
# }
# data = ng.get_fromDate(body)
# print(data)






# table = 'NI_News_Industry'
# field_list = ['EventCode','EventEmotionCode','EventDate']
# filt_date = 'InsertTime'
# s_date = '2020-01-01'
# e_date = '2020-07-28'
#
# body = {
#     "table": table,
#     "field_list": field_list,
#     "alterField": filt_date,
#     "startDate": s_date,
#     "endDate": e_date,
# }
#
# df = ng.get_fromDate(body)
# print(df)



# table = 'LC_Dividend'
# field_list = ['EventCode','EventEmotionCode','EventDate']
# filt_date = 'InsertTime'
# s_date = '2020-01-01'
# e_date = '2020-07-28'
#
# body = {
#     "table": table,
#     "field_list": field_list,
#     "alterField": filt_date,
#     "startDate": s_date,
#     "endDate": e_date,
# }
#
# df = ng.get_fromDate(body)
# print(df)



# table = 'NI_News_Industry_SE'
# field_list = ['ID','TypeCode','Code']
#
# body = {
#     "table": table,
#     "field_list": field_list
# }
# df = ng.get_fromTable(body)
# print(df)
#
#
# table = 'CT_SystemConst'
# field_list = ['LB','DM','LBMC']
#
# body = {
#     "table": table,
#     "field_list": field_list
# }
# df = ng.get_fromTable(body)
# print(df)



# table = 'C_RR_ResearchReport'
# field_list = ["OrgName", "OrgNameDisc", "AreaCode", "Author", "WritingDate", "InsertTime"]
# name = ['国泰君安', '中信证券']
#
# body = {
#     "table": table,
#     "field_list": field_list,
#     "alterFieldName": "OrgNameDisc",
#     "name": name,
#     "alterFieldDate": "InfoPublDate",
#     "startDate": "2020-05-01",
#     "endDate": "2020-07-07"
# }
# data = ng.get_fromDateName(body=body)
# print(data)

# t1 = time.time()
#
#
# price = ng.get_price(codes=['000001.SZ', '600000.SH', '000028.SZ', "000858.SZ", "600722.SH", "000895.SZ", "600006.SH"])
# print(price)



# body = {
#     'stock_list': ['002340.SZ'],
#     'start': '2021-03-18',
#     'end': '2021-04-30',
#     'field_list':
#         [
#             'bigBuyOrder_open',
#             'bigSaleOrder_open',  # 净额/amount
#             'bigActiveSaleOrder_close',
#             'Amount',
#         ]
# }
# df_L2 = ng.getFactor(body=body)
# print(df_L2)


# body = {
#     'stock_list': ['002340.SZ'],
#     'start': '2020-03-18',
#     'end': '2021-06-10',
#     'field_list':
#         [
#             'LogSize',
#             'Vol_DailyStd',
#             'MidSize',
#             'MLev',
#             'IndustryZX'
#         ]
# }
# data = ng.getRiskFactor(body=body)
# print(data)

# data = ng.getRiskFactorColumns()
# print(data)



# for i in range(50):
#     ss = '2021-04-21'
#     ee = '2021-05-06'
#     ddd = ng.get_north_jg(ss,ee)
#     # print(ddd)
#     print(len(ddd))
#     if len(ddd) == 1:
#         print(ddd)
#     time.sleep(1)







# data = ng.get_free_value(['002615.SZ','000001.SZ'], "2015-03-09", "2015-03-14")
# print(data)




# print(time.time()-t1)




# data = ng.get_stock_data(code='399006.SZ', freq='1m', adj='qfq', bars=300)
# print(data)

# data = ng.get_stock_data(code='399006.SZ', freq='5m', adj='qfq', bars=300)
# print(data)
# data = ng.get_stock_data(code='399006.SZ', freq='15m', adj='qfq', bars=300)
# print(data)
# data = ng.get_stock_data(code='399006.SZ', freq='30m', adj='qfq', bars=300)
# print(data)
# data = ng.get_stock_data(code='399006.SZ', freq='60m', adj='qfq', bars=300)
# print(data)

# data = ng.get_stock_data(code='399006.SZ', freq='w', adj='qfq', bars=50)
# print(data)
# data = ng.get_stock_data(code='399006.SZ', freq='mon', adj='qfq', bars=50)
# print(data)
#
#
# data = ng.get_stock_data(code='399006.SZ', freq='d', adj='qfq', bars=50)
# print(data)

# data = ng.get_stock_data(code='399006.SZ', freq='d', adj='qfq', start='2019-05-27', end='2020-08-27')
# print(data)

# data = ng.get_stock_data(code='000590.SZ', freq='d', adj='qfq', start='2020-08-26', end='2020-08-27')
# print(data)

# data = ng.get_stock_data(code='000590.SZ', freq='d', adj='qfq', bars=2)
# print(data)


# df = ng.get_allStock()
# print(df)
# a = df[df['code']=='600519.SH']
# print(a)


# df = ng.get_allStock()
# print(df)
# print(time.time()-t1)
#
# df = ng.get_allStockNew()
# print(df)
# print(time.time()-t1)

# data = ng.getRZRQStock(start='2021-06-14', end='2021-06-15', stock_list=['000001.SZ', '600016.SH', '300383.SZ'])
# print(data)



# data = ng.get_free_value(['002615.SZ','000001.SZ'], "2021-06-02", "2021-06-15")
# print(data)



# t11 = time.time()
#
# df = float(ng.get_k_data(code='000058.SZ',freq='d',end='2020-05-15',bars=1)['close'].tolist()[0])
# print(df)
#
# print(time.time()-t11)



# body = {
#     "table": 'SecuMain',
#     "field_list": ['SecuCode', 'SecuAbbr', 'SecuMarket', 'ListedSector', 'ListedState'],
#     "alterFieldName": 'SecuCategory',
#     "name": [1],
# }
# dfgb_all_code = ng.get_fromName(body)
# print(dfgb_all_code)
# df = ng.get_allStock()
# print(df)
# innerCode = df[df['code'] == '000058.SZ']['innercode'].tolist()[0]
# print(innerCode)
#
#
# print(time.time()-t11)


# t1 = time.time()
#
# data = ng.get_stock_data_inner_raw(innercode=661, freq='5m', adj='qfq', bars=400)
# print(data)
#
# print(time.time()-t1)
#
#
# t1 = time.time()
#
# data = ng.get_stock_data_inner(code='002153.SZ',innercode=661, freq='5m', adj='qfq', bars=400)
# # print(data)
#
# print(time.time()-t1)




# t1 = time.time()
#
# data = ng.get_stock_data_inner_raw(innercode=661, freq='d', adj='qfq', bars=400)
# print(data)
#
# print(time.time()-t1)
#
#
# t1 = time.time()
#
# data = ng.get_stock_data_inner(code='002153.SZ',innercode=661, freq='d', adj='qfq', bars=400)
# print(data)
#
# print(time.time()-t1)


# table = 'C_RR_ResearchReport_SE'
# field_list = ['ID', 'TypeCode', 'Code']
# body = {
#     "table": table,
#     "field_list": field_list,
#     "alterFieldName": 'ID',
#     "name": [649189259854, 649185930937, 649181845390, 649186813096, 649186754842]
# }
# df2 = ng.get_fromName(body)
# print(df2)





# df = ng.get_tick('002153.SZ')
# print(df)



# t1 = time.time()
#
# df = ng.get_trans(codes=['002153.SZ',1,'300856.SZ',12,'688580.SH'])
# print(df)

#
# print(time.time()-t1)



# t1 = time.time()

# df = ng.get_price(codes=['002153.SZ','300856.SZ','688580.SH'])
# print(df)


# print(time.time()-t1)


# while True:
#     a = ng.get_zjlx()
#     print(a, end='    ')
#     print(str(datetime.datetime.now())[:19])
#     time.sleep(1)





# data = ng.get_stock_data_inner(code='002437.SZ', innercode=945, freq='5m', adj='qfq', bars=300)
# print(data)

# data = ng.get_stock_data_inner(code='000001.SH', innercode=2318, freq='5m', adj='qfq', bars=300)
# print(data)




# data = ng.get_plate_data_inner(code='asdasd', innercode=2000018, freq='5m', adj='qfq', bars=300)
# print(data)
# # #
# # # a = data['date'].values[-1]
# # # print(a,type(a))
# #
# data = ng.get_plate_data_inner_raw(innercode=2000018, freq='5m', adj='qfq', bars=300)
# print(data)

# h = ng.get_stock_data(code="002705.SZ",  freq='30m', adj='qfq', end = '2020-08-31' ,bars=1000)
# print(h)

# h = ng.get_stock_data(code="600507.SH",  freq='d', adj='qfq', start='2015-01-01',end = '2016-08-31')
# print(h)


# h_raw = ng.get_stock_data(code='000001.SZ', innercode=1, freq='30m', adj='qfq', bars=300)
# print(h_raw)
# h_raw = ng.get_stock_data(code='000001.SZ', innercode=1, freq='5m', adj='qfq', bars=300)
# print(h_raw)
# h_raw = ng.get_stock_data(code='000001.SZ', innercode=1, freq='15m', adj='qfq', bars=300)
# print(h_raw)
# h_raw = ng.get_stock_data(code='000001.SZ', innercode=1, freq='60m', adj='qfq', bars=300)
# print(h_raw)
# h_raw = ng.get_stock_data(code='000001.SZ', innercode=1, freq='1m', adj='qfq', bars=10)
# print(h_raw)
# h_raw = ng.get_stock_data(code='000001.SZ', innercode=1, freq='1m', adj='qfq', end='2019-01-05',bars=20)
# print(h_raw)


# data = ng.get_stock_data(code='000029.SZ', freq='d', adj='qfq', end='2020-08-05',bars=300)
# print(data)


# stock_data = ng.get_allOnlyStock()
# print(stock_data)
#
# new_code = [str(i)[:6] for i in stock_data['code']]
#
# stock_data['code'] = new_code
# print(stock_data[['code','innercode','name','market']])



# ng.get_stock_data_inner(code='002437.SZ', innercode=945, freq='d', adj='qfq', bars=3)




# value = ng.get_depth('002534.SZ')
# print(value)

# aa = value['bids'][0][0]
# print(round(float(aa),4),type(aa))
#
# bb = value['asks'][0][0]
# print(round(float(bb),4),type(bb))
#
# if round(float(bb),4) == 0:
#     print('asdasd')



# innerlist=[1,2,3]
# data = ng.get_turnover(innerlist)
# print(data)






# a = ng.get_stock_data_inner(code='000300.SH',innercode=2131, freq='1m', bars=100)
# print(a)


# bm_value = ng.get_stock_data_inner(code='000300.SH',innercode=2131, freq='d', bars=1).close.values[-1]
# print(bm_value)



# ng.get_fromCode()
# ng.get_fromCompany()
# ng.get_fromDate()
#
# ng.get_fromDateName()
# ng.get_fromTable()
# ng.get_fromName()


# body = {
#         "table": 'QT_TradingDayNew',
#         "field_list": ['TradingDate', 'IfTradingDay', 'SecuMarket'],
#         "alterField": 'TradingDate',
#         "startDate": '2018-01-01',
#         "endDate": '2022-01-01'
# }
# data = ng.get_fromDate(body)
# print(data)




# body = {'table': 'C_EX_StockNetProfit',
#         'field_list': ['SecuCode','EndDate', 'StatisPeriod', 'StatisType', 'PNetProfitCount', 'PNetProfitAdd', 'PNetProfitReduce', 'ForecastYear'],
#         'startDate': '2020-09-17',
#         'endDate': '2020-09-17',
#         'alterFieldDate': 'EndDate',
#         'alterFieldName': 'StatisPeriod',
#         'name': [30]}
# data = ng.get_fromDateName(body)
# print(data)



# table = 'C_RR_ResearchReport'
# field_list = ["OrgName", "OrgNameDisc", "AreaCode", "Author", "WritingDate", "InsertTime"]
# # name = ['国泰君安']
# name = ['国泰君安', '中信证券']
#
# body = {
#     "table": table,
#     "field_list": field_list,
#     "alterFieldName": "OrgNameDisc",
#     "name": name,
#     "alterFieldDate": "InfoPublDate",
#     "startDate": "2020-05-01",
#     "endDate": "2020-07-07"
# }
# data = ng.get_fromDateName(body=body)
# print(data)



# bm_value = ng.get_k_data(code='000905.SH', freq='d', start='2020-09-23', end='2020-09-23').close.values[-1]
# print(bm_value)

# bm_value = ng.get_k_data(code='000300.SH', freq='d', start=t_date, end=t_date).close.values[-1]

# df_ = ng.get_k_data(code='000300.SH', freq='d', start='2019-09-23', end='2020-09-23')
# print(df_)

# history_data = df_.loc[df_["date"] <= '2020-04-20 00:00:00'][-30:].reset_index(drop=True)
# print(history_data)

# df_data = history_data.drop([0])
# print(df_data)

# df_data = history_data.iloc[:-1]
# print(df_data)



# df_data = history_data.drop([-1])
# print(df_data)
# body = {'table': 'C_EX_StockNetProfit',
#         'field_list': ['EndDate', 'StatisPeriod', 'StatisType', 'PNetProfitCount', 'PNetProfitAdd', 'PNetProfitReduce', 'ForecastYear'],
#         'alterField': 'EndDate',
#         'startDate': '2020-09-17',
#         'endDate': '2020-09-17',
#         'all_code': True}
#
# data = ng.get_fromCode(body)
# print(data)




# table = 'C_EX_DataStock'
# field_list = ["InnerCode","EndDate","StatisPeriod","ForecastYear","SecuCode","NetProfitAvg"]
#
# body = {
#     "table": table,
#     "field_list": field_list,
#     "alterField": "EndDate",
#     "startDate": "2020-07-05",
#     "endDate": "2020-07-07",
# }
# data = ng.get_fromDate(body=body)
# print(data)




# data = ng.get_ShareHolding(type='SZ', start='2021-04-07', end='2021-04-08')
# print(data)
# data = ng.get_ShareHolding(type='SH', start='2021-04-07', end='2021-04-08')
# print(data)
# data = ng.get_ShareHolding(type='HKSHSZ', start='2020-09-01', end='2020-09-28')
# print(data)





# data = ng.get_HKTradeCalendar(start='2020-09-01', end='2020-10-20')
# print(data)
#
# df_SZ = ng.get_ShareHolding(type='SZ', start='2020-10-09', end='2020-10-16')
# print(df_SZ)





# data = ng.get_stock_data(code='300940.SZ', freq='d',adj='qfq', end='2021-02-05',bars=2, innercode=249)
# print(data)



# data = ng.get_stock_data(code='000661.SH', freq='d',adj='qfq', end='2019-01-09',bars=2, innercode=249)
# print(data)


# data = ng.get_north_capital(start_date='2020-09-01', end_date='2020-09-01')
# print(data)


# data = ng.get_north_top10(start_date='2020-09-01', end_date='2020-09-01')
# print(data)


# stock_close_df = ng.get_stock_data(code='600175.SH', freq='d', adj='qfq', bars=1)
# print(stock_close_df)

# stock_close_df = ng.get_stock_data(code='600109.SH', freq='1m', adj='qfq', start='2019-10-09', end='2020-10-09')
# print(stock_close_df)

# stock_close_df = ng.get_stock_data(code='000661.SZ', freq='d', adj='qfq', end='2019-02-25', bars=1)
# print(stock_close_df)



# stock_close_df = ng.get_stock_data(code='000661.SZ', freq='d', adj='qfq', bars=1)
# print(stock_close_df)
#
# stock_close_df = ng.get_stock_data(code='000661.SZ', freq='d', adj='qfq', bars=1)['close'].tolist()[0]
# print(stock_close_df)
# print(type(stock_close_df))
# data = ng.get_stock_data(code='000661.SZ', freq='d', adj='qfq', bars=2)
# value = round(float(data.iloc[-1]['close']), 4)  # open_price
# print(value)



# print(stock_close_df['close'].tolist()[0])
# print(type(stock_close_df['close'].tolist()[0]))



# stock_close_df = ng.get_stock_data(code='000001.SZ', freq='d', adj='qfq', end='2020-10-25', bars=1)
# print(stock_close_df)



# stock_close_df = ng.get_stock_data(code='603058.SH', freq='d', adj='qfq', bars=1)
# print(stock_close_df)



# stock_close_df = ng.get_stock_data(code='603058.SH', freq='d', adj='qfq', start="2020-10-13",end="2020-10-13")
# print(stock_close_df)




# print(stock_close_df.shape)
# if stock_close_df.shape[0] > 0:  # 退市或停牌处理
#     print('asdas')



# data = ng.get_allPlate()
# print(data)
#
# d = h_raw = ng.get_plate_data_inner(code='880003', innercode=2000002, freq='d', adj='qfq', bars=300)
# print(d)



# data = ng.get_plate_data_inner(code=886219, innercode=2000500, freq='d', adj='qfq', bars=20)
# print(data)
#
# data = ng.get_plate_data_inner(code=886219, innercode=2000500, freq='d', adj='qfq', end='2020-09-01',bars=20)
# print(data)
#
# data = ng.get_plate_data_inner(code=886219, innercode=2000500, freq='d', adj='qfq', start='2020-08-05',end='2020-09-01')
# print(data)
#
# data = ng.get_plate_data_inner(code=886219, innercode=2000500, freq='d', adj='qfq', start='2020-09-01',end='2020-09-01')
# print(data)


# data = ng.get_allStock()
# print(data)
#
# # 获取A股所有股票代码+退市
# data = ng.get_allStockNew()
# print(data)



# data = ng.get_allStockData(adj='qfq',date='2021-06-04')
# print(data)



# ng.get_depth()


# a = ng.get_allStockData(adj='qfq',date='2012-02-22')
# print(a)


# a = ng.get_allStockData(adj='hfq',date='2020-10-30')
# print(a)
#
# a = ng.get_allStockData(date='2020-10-30')
# print(a)



# t11 = time.time()
# import ngwshare as ng

# # 获取全部基金
# data = ng.get_all_funds()
# print(data)
# a = data.loc[data['TradingCode'] == '515050.SH']
# print(a)

# a = ng.get_allStockNew()
# print(a)
#

# a = ng.get_fund_data(code='510300.SH', innercode=5236, freq='d', adj='qfq', bars=20)
# print(a)
#
# data = ng.get_north_jg("2020-08-17", "2020-08-19")
# print(data)


# t1 = time.time()
# body = {
#     "table": 'LC_SecuChange',
#     "field_list": ['InnerCode', 'SecurityAbbr', 'InfoPublDate',
#                    'IfPassed', 'ChangeDate', 'ChangeReason'],
# }
# STInfo = ng.get_fromTable(body)
# print(STInfo)
#
# print(time.time()-t1)



# body = {
#         "table": 'LC_SecuChange',
#         "field_list": ['InnerCode', 'SecurityAbbr', 'InfoPublDate', 'IfPassed', 'ChangeDate','ChangeReason'],
#         "alterField": 'InfoPublDate',
#         "startDate": '2010-01-01 00:00:00',
#         "endDate": '2022-01-01 00:00:00'
# }
# data = ng.get_fromDate(body)
# print(data)





# a = ng.get_fund_data(code='510300.SH', innercode=5236, freq='d', adj='qfq', end='2020-11-30', bars=20)
# print(a)
# a = ng.get_fund_data(code='510300.SH', innercode=5236, freq='1m', adj='qfq', start='2020-11-02', end='2020-11-30')
# print(a)
#
# # a = ng.get_fund_data(code='510300.SH', freq='d', adj='qfq', bars=20)
# # print(a)
# # a = ng.get_fund_data(code='510300.SH', freq='d', adj='qfq', end='2020-11-30', bars=20)
# # print(a)
# # a = ng.get_fund_data(code='510300.SH', freq='d', adj='qfq', start='2020-11-01', end='2020-11-30')
# # print(a)
#
# print(time.time()-t11)






# h = ng.get_stock_data(code="000001.SZ", innercode=1,  freq='1m', end = "2020-09-01" ,bars=250)
# print(h)



# a = ng.get_funds_depth(code='510300.SH')
# print(a)
#
# a = ng.get_funds_depth(code='159949.SZ')
# print(a)
# a = ng.get_funds_depth(code='510050.SH')
# print(a)


# to_mail = 'wj296348304@163.com'
# mail_header = '【数据产品】【龙虎榜】'
# mail_content = '[信息]数据保存成功！！！'
# mail_flag = ng.send_mail(to_mail, mail_header, mail_content)
# print(mail_flag)



# h_last = ng.get_price(['000002.SZ','000001.SZ','300616.SZ','510800.SH','511880.SH'])
# print(h_last)

# data = ng.get_hxl2()
# print(data)



# data = ng.get_stock_data(code='000001.SZ', freq='1m', adj='qfq', bars=3)
# print(data)
# data = ng.get_stock_data(code='000001.SH', freq='1m', adj='qfq', bars=3)
# print(data)


# a = ng.get_price(codes=)
#


# data = ng.get_allStock()
# print(data)
# print(data[:20])

# data = ng.get_all_funds()
# print(data)
# a = data.loc[data['TradingCode'] == '515050.SH']
# print(a)


# a = ng.get_allPlate()
# print(a)



# a = ng.get_funds_depth(code='150270.SZ',innercode=7548)
# print(a)

# a = data.loc[data['TradingCode'] == '150270.SZ']
# print(a)


# # code = '511880.SH'
# code = '510300.SH'
# a = data.loc[data['TradingCode'] == code]['InnerCode'].tolist()[0]
# print(a)
# print(type(a))



# a = data.loc[data['TradingCode'] == '150270.SZ']
# print(a)
#
# a = ng.get_fund_data(code='150270.SZ', innercode=5662, freq='d', adj='qfq', end='2020-11-30', bars=1)
# print(a)



# a = ng.get_fund_data(code='511880.SH', innercode=5662, freq='d', adj='qfq', end='2020-11-30', bars=1)
# print(a)


# a = ng.get_fund_data(code='511880.SH', innercode=5662, freq='d', adj='qfq', bars=1)
# print(a)

#
# bm_data = ng.get_fund_data(code='511880.SH', innercode=5662, freq='d', adj='qfq', bars=2)
# print(bm_data)
# bm_value = round(float(bm_data.iloc[-1]['close']), 4)
# print(bm_value)
#
# bm_data = ng.get_stock_data_inner(code='000300.SH', innercode=2131, freq='d', bars=2)
# print(bm_data)
# bm_value = round(float(bm_data.iloc[-1]['close']), 4)
# print(bm_value)


# data = ng.get_allStock()
# print(data)
# a = data[data['code']=='002594.SZ']
# print(a)



# innercode = data.loc[data['code']=='000001.SH']['innercode'].tolist()[0]
# print(innercode)
# stock_close_df = ng.get_stock_data(code='000001.SH',innercode=innercode, freq='d', adj='qfq', bars=2)
# print(stock_close_df)
#
# value = round(float(stock_close_df.iloc[0]['close']), 4)
# print(value)
#
#
# open = stock_close_df['open'].tolist()[0]
# print(open)
# close = stock_close_df['close'].tolist()[0]
# print(close)


# bm_data = ng.get_stock_data_inner(code='000016.SH', innercode=2122, freq='d', bars=2)
# print(bm_data)
# bm_value = round(float(bm_data.iloc[-1]['close']), 4)
# print(bm_value)



# ng.get_plate_data_inner()
#
# h  = ng.get_stock_data(code='000001.SZ', freq='1m', adj='qfq', start='2021-05-06', end='2021-05-06')
# print(h)


# h = ng.get_stock_data(code='000010.SH', innercode=2324,adj='qfq', freq='1m',bars=1500)
# print(h)
# h = ng.get_stock_data(code='000010.SH', innercode=2324,adj='qfq', freq='1m', end = "2020-09-04" ,bars=1500)
# print(h)
#
# h = ng.get_stock_data(code='000010.SH', innercode=2324,adj='qfq', freq='1m', start='2020-08-01',end = "2020-09-04")
# print(h)



# bm_data = ng.get_stock_data(code='000016.SH', freq='d', adj='qfq', end='2020-10-23', bars=2)
# print(bm_data)
# print(bm_data['close'].tolist()[-1])
# bm_value = round(float(bm_data.iloc[-1]['close']), 4)
# print(bm_value)

# bm_value = ng.get_k_data(code='000016.SH', freq='d', start='2020-10-23', end='2020-10-23').close.values[-1]
# print(bm_value)


# h = ng.get_stock_data(code='002705.SZ', innercode=1212,  freq='1m', end = "2019-01-02" ,bars=1000)
# print(h)



# import tushare as ts
# tok = "5e8c8dc53d0b3a660989d14fc4b998cd865a27c9fe2e805246bfd9b3"
# pro = ts.pro_api(token=tok)
#
# df = ts.pro_bar(ts_code='000001.SZ', freq='D',adj='qfq', start_date='2018-01-01 09:00:00', end_date='2018-10-11 15:00:00')
# print(df)



# data = ng.get_allStockData(adj='qfq',date='2021-05-10')
# print(data)





# a = ng.return_last_trading_day()
# print(a)

# data = ng.get_allStock()
# print(data)


# a = ng.return_last_trading_day()
# print(a)


# a = ng.get_allStockData(adj='qfq', date='2020-01-07')
# print(a)


# stock_close_df = ng.get_stock_data(code='600109.SH', freq='1m', adj='qfq', bars=200)
# print(stock_close_df)
# stock_close_df = ng.get_stock_data(code='600109.SH', freq='30m', adj='qfq', start='2015-12-07', end='2018-12-09')
# print(stock_close_df)
# stock_close_df = ng.get_stock_data(code='600109.SH', freq='1m', adj='qfq', start='2020-12-07 10:30:00', end='2020-12-09 14:30:00')
# print(stock_close_df)
# stock_close_df = ng.get_stock_data(code='600109.SH', freq='1m', adj='qfq', end='2020-12-09', bars=200)
# print(stock_close_df)
# stock_close_df = ng.get_stock_data(code='600109.SH', freq='1m', adj='qfq', end='2020-12-09 13:58:00', bars=200)
# print(stock_close_df)


# stock_close_df = ng.get_stock_data(code='600109.SH', freq='5m', adj='qfq', bars=200)
# print(stock_close_df)
# stock_close_df = ng.get_stock_data(code='600109.SH', freq='5m', adj='qfq', start='2020-11-09', end='2020-12-09')
# print(stock_close_df)
# stock_close_df = ng.get_stock_data(code='600109.SH', freq='5m', adj='qfq', start='2020-11-09 10:30:00',
#                                    end='2020-12-09 14:30:00')
# print(stock_close_df)
# stock_close_df = ng.get_stock_data(code='600109.SH', freq='5m', adj='qfq', end='2020-12-09', bars=200)
# print(stock_close_df)
# stock_close_df = ng.get_stock_data(code='600109.SH', freq='5m', adj='qfq', end='2020-12-09 14:00:00', bars=200)
# print(stock_close_df)





# t_date = '2021-02-03'
# bm_value = ng.get_k_data(code='399006.SZ', freq='d', start=t_date, end=t_date).close.values[-1]
# print(bm_value)
#
# print(ng.get_k_data(code='399006.SZ', freq='d', start=t_date, end=t_date))
#
# bm_data = ng.get_stock_data_inner(code='399006.SZ', innercode=2121, freq='d', bars=2)
# print(bm_data)


# data = ng.get_stock_data_inner(code='000300.SH',innercode=2131, freq='d', bars=2)
# print(data)


# bm_value = ng.get_fund_data(code='511880.SH', innercode=5662, freq='d', adj='qfq', bars=2)
# print(bm_value)
#
# all_funds = ng.get_all_funds()
# print(all_funds)



# bm_value = round(float(bm_data.iloc[-1]['close']), 4)
# print(bm_value)


# a = ng.get_all_funds()
# print(a)
# b = a.loc[a.TradingCode=='515790.SH']
# print(b)
#
#
# c = ng.get_fund_data(innercode=95444,code='515790.SH',freq='d', adj='qfq',end='2021-02-03',bars=10)
# print(c)


# a = ng.sent_dingding2('asdasdasd',[13087005272],False)
# print(a)

# ng.sent_dingding2('【success】两融-综合数据！',[13087005272],False)
#
# ng.sent_dingding2('【success】两融-综合数据！',[13087005272],False)


# t_date = '2021-02-03'
#
# bm_value = ng.get_k_data(code='688004.SH', freq='d', start=t_date, end=t_date)
# print(bm_value)


# data = ng.get_hisTick(symbol='rb2103',exchange='SHFE',start='2021-02-01 13:30:00',end='2021-02-02 14:30:00')
# print(data)


print(time.time()-t1)


import ngwshare as ng
import pandas as pd
import warnings
warnings.filterwarnings("ignore")
pd.set_option('display.max_rows',5000)
pd.set_option('display.max_columns',5000)
pd.set_option('display.width',10000)


# # 获取所有场外基金代码
# data = ng.get_AllOTCFundsInfo()
# print(data.loc[:300])
# df = data

# a = df[df['FundCode'] == '000879']['FundName'].tolist()[0]
# print(a)

# a = ng.get_k_data(code='000300.SH', freq='d', start='2021-01-28', end='2021-01-28').close.values[0]
# print(a)

# # 净值
# data = ng.get_OTCFundsValues(code='000003',start='2020-10-13',end='2021-01-18')
# print(data)



code = '000879'


# # 简要信息
# data = ng.get_OTCFundsInfo(innercode=22035)
# print(data)

# OTC_DATA_i = ng.get_OTCFundsValues(code="000003", start="2013-10-13", end="2021-01-22")
# print(OTC_DATA_i)

# inn = 95061
# # 净值
# data = ng.get_OTCFundsValues(innercode=inn)
# print(data)
# # 简要信息
# data = ng.get_OTCFundsInfo(innercode=inn)
# print(data)



# data = ng.get_OPF_Bouns(code=code)
# print(data)










def deal_adjprice(etfcode,startday,endday):
    OTC_DATA_i = ng.get_OTCFundsValues(code=etfcode, start=startday, end=endday)
    # print(OTC_DATA_i)
    OTC_DATA_i["Date"] = pd.to_datetime(OTC_DATA_i["Date"])
    OTC_DATA_i.sort_values(by="Date", ascending=True, inplace=True)
    print(OTC_DATA_i)

    Bouns_i = ng.get_OPF_Bouns(code=etfcode)
    Bouns_i["ChuXiDate"] = pd.to_datetime(Bouns_i["ChuXiDate"])
    # Bouns_i["Date"] = [last_trading_day(date, tradingdays) for date in Bouns_i["ChuXiDate"]]
    Bouns_i["Date"] = Bouns_i["ChuXiDate"]
    # print(Bouns_i)

    flag = (Bouns_i["Date"]>=pd.to_datetime(startday))&(Bouns_i["Date"]<=pd.to_datetime(endday))
    # print(flag)
    # print(type(flag))

    Bouns_i = Bouns_i[flag]
    print(Bouns_i)

    OTC_DATA_i = pd.merge(OTC_DATA_i,Bouns_i.loc[:,["Date","Bonus"]],how="outer")
    print(OTC_DATA_i)

    OTC_DATA_i["Bonus"].fillna(0,inplace=True)
    print(OTC_DATA_i)

    # OTC_DATA_i["PerNetValue_1"] = OTC_DATA_i["PerNetValue"] - OTC_DATA_i["Bonus"]
    # OTC_DATA_i["PerNetValue_1"] = OTC_DATA_i["PerNetValue_1"].shift(1)
    # OTC_DATA_i["rets"] = OTC_DATA_i["PerNetValue"]*1.0/OTC_DATA_i["PerNetValue_1"] - 1
    OTC_DATA_i["rets"] = (OTC_DATA_i["PerNetValue"] + OTC_DATA_i["Bonus"])/OTC_DATA_i["PerNetValue"].shift(1) - 1
    print(OTC_DATA_i)

    OTC_DATA_i["rets"][0] = 0
    print(OTC_DATA_i)

    OTC_DATA_i["hfq_price"] = OTC_DATA_i["rets"] + 1
    print(OTC_DATA_i)

    PerNetValue0 = OTC_DATA_i["PerNetValue"][0]
    print(PerNetValue0)

    print(OTC_DATA_i["hfq_price"])
    print(OTC_DATA_i["hfq_price"].cumprod())

    OTC_DATA_i["hfq_price"] = OTC_DATA_i["hfq_price"].cumprod() * PerNetValue0
    print(OTC_DATA_i)

    PerNetValue_1 = list(OTC_DATA_i["PerNetValue"])[-1]
    print(PerNetValue_1)
    hfqprice_1 = list(OTC_DATA_i["hfq_price"])[-1]
    OTC_DATA_i["qfq_price"] = OTC_DATA_i["hfq_price"]/hfqprice_1*PerNetValue_1

    return OTC_DATA_i




adjprice = deal_adjprice(code,'2020-05-01','2020-12-30')
print(adjprice)













__author__ = 'wangjian'

import requests
import json
import traceback
import random
import pandas as pd


def get_ua():
    first_num = random.randint(55, 62)
    third_num = random.randint(0, 3200)
    fourth_num = random.randint(0, 140)
    os_type = [
        "(Windows NT 6.1; WOW64)", "(Windows NT 10.0; WOW64)", "(X11; Linux x86_64)",
        "(Macintosh; Intel Mac OS X 10_12_6)"
    ]
    chrome_version = "Chrome/{}.0.{}.{}".format(first_num, third_num, fourth_num)
    ua = " ".join(["Mozilla/5.0", random.choice(os_type), "AppleWebKit/537.36",
                   "(KHTML, like Gecko)", chrome_version, "Safari/537.36"])
    return ua



def get_OPF_Bouns(code=None):
    url = 'https://stq.niuguwang.com/funds/Bonus?code={}'.format(code)
    # print(url)
    try:
        headers = {"Content-Type": "application/json",
                   'User-Agent':get_ua()}
        response = requests.get(url, headers=headers).content.decode()
        response_json = json.loads(response)
        df_data = pd.DataFrame(response_json['data'])
        return df_data[['FundCode','DengJiDate','ChuXiDate','FaFangDate','Bonus','Bonus','AddTime']]\
            .sort_values(by=["ChuXiDate"],ascending=[False])
    except Exception:
        print(traceback.format_exc())



if __name__ == '__main__':
    import ngwshare as ng
    import datetime

    code = '000001'
    data = ng.get_OPF_Bouns(code=code)
    print(data)





__author__ = 'wangjian'
from ngwshare.utils.http_util import get_ua
import requests
import traceback
import json
import pandas as pd


def get_USKline(symbol=None,klineType=None,end=None,count=None):
    try:
        if end:
            url = "http://testcaklineus.huanyingzq.com/USKline/Kline?symbol={}&klineType={}&end={}&count={}".format(symbol,klineType,end,count)
        else:
            url = "http://testcaklineus.huanyingzq.com/USKline/Kline?symbol={}&klineType={}&count={}".format(symbol,klineType,count)
        headers = {'User-Agent': get_ua()}
        response = requests.get(url, headers=headers)
        response.close()
    except Exception:
        print(traceback.format_exc())
    else:
        try:
            response_json = json.loads(response.content.decode())
            # print(response_json)
            if response_json.get('code') == 0:
                return pd.DataFrame(response_json.get('data'))
            else:
                return None
        except:
            return None






















